@@ -76,7 +76,7 @@ const H5std_string    FILE4("tfile4.h5");
  *                     cases.  Since there are no operator<< for 'long long'
  *                     or int64 in VS C++ ostream, I casted the hsize_t values
  *                     passed to verify_val to 'long' as well.  If problems
- *                     arises later, this will have to be specificly handled
+ *                     arises later, this will have to be specifically handled
  *                     with a special routine.
  *-------------------------------------------------------------------------
  */
@@ -282,7 +282,7 @@ static void test_file_create()
  *                     cases.  Since there are no operator<< for 'long long'
  *                     or int64 in VS C++ ostream, I casted the hsize_t values
  *                     passed to verify_val to 'long' as well.  If problems
- *                     arises later, this will have to be specificly handled
+ *                     arises later, this will have to be specifically handled
  *                     with a special routine.
  *-------------------------------------------------------------------------
  */
@@ -575,7 +575,7 @@ static void test_file_attribute()
         verify_val(num_objs, 0, "H5File::getObjCount(H5F_OBJ_DATATYPE)", __LINE__, __FILE__);
         num_objs = file5.getObjCount(H5F_OBJ_FILE);
         verify_val(num_objs, 1, "H5File::getObjCount(H5F_OBJ_FILE)", __LINE__, __FILE__);
-        
+
         // Get the file name using the attributes
         H5std_string fname = fattr1.getFileName();
         verify_val(fname, FILE5, "H5File::getFileName()", __LINE__, __FILE__);
@@ -657,8 +657,15 @@ static void test_libver_bounds_real(
     unsigned obj_version = file.childObjVersion(ROOTGROUP);
     verify_val(obj_version, oh_vers_create, "H5File::childObjVersion", __LINE__, __FILE__);
 
+    // Verify object header version another way
+    H5O_info_t oinfo;
+    HDmemset(&oinfo, 0, sizeof(oinfo));
+    file.getObjinfo(oinfo, H5O_INFO_HDR);
+    verify_val(oinfo.hdr.version, oh_vers_create, "H5File::getObjinfo", __LINE__, __FILE__);
+
     /*
-     * Reopen the file and make sure the root group still has the correct version
+     * Reopen the file and make sure the root group still has the correct
+     * version
      */
     file.close();
 
@@ -678,6 +685,11 @@ static void test_libver_bounds_real(
     obj_version = group.objVersion();
     verify_val(obj_version, oh_vers_mod, "Group::objVersion", __LINE__, __FILE__);
 
+    // Verify object header version another way
+    HDmemset(&oinfo, 0, sizeof(oinfo));
+    group.getObjinfo(oinfo, H5O_INFO_HDR);
+    verify_val(oinfo.hdr.version, oh_vers_mod, "Group::getObjinfo", __LINE__, __FILE__);
+
     group.close(); // close "/G1"
 
     /*
@@ -914,7 +926,7 @@ static void test_file_info()
     /*  ret=H5Pget_shared_mesg_nindexes(fcpl2,&nindexes);
     CHECK(ret, FAIL, "H5Pget_shared_mesg_nindexes");
     VERIFY(nindexes, MISC11_NINDEXES, "H5Pget_shared_mesg_nindexes");
- */ 
+ */
 
         // Get and verify the file space info from the creation property list */
         fcpl2.getFileSpaceStrategy(out_strategy, out_persist, out_threshold);
