@@ -12,7 +12,7 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke <matzke@llnl.gov>
+ * Programmer:  Robb Matzke
  *              Monday, August  2, 1999
  *
  * Purpose:	The public header file for the sec2 driver.
@@ -20,8 +20,6 @@
 #ifndef H5FDsec2_H
 #define H5FDsec2_H
 
-#include "H5Ipublic.h"
-
 #define H5FD_SEC2	(H5FD_sec2_init())
 
 #ifdef __cplusplus
@@ -29,7 +27,6 @@ extern "C" {
 #endif
 
 H5_DLL hid_t H5FD_sec2_init(void);
-H5_DLL void H5FD_sec2_term(void);
 H5_DLL herr_t H5Pset_fapl_sec2(hid_t fapl_id);
 
 #ifdef __cplusplus
