@@ -5,19 +5,17 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at the  *
- * root level of an installed copy of the electronic HDF5 document set and   *
- * is linked from the top-level documents page.  It can also be found at     *
- * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*-------------------------------------------------------------------------
  *
  * Created:             H5Faccum.c
  *                      Jan 10 2008
- *                      Quincey Koziol <koziol@hdfgroup.org>
+ *                      Quincey Koziol
  *
  * Purpose:             File metadata "accumulator" routines.  (Used to
  *                      cache small metadata I/Os and group them into a
@@ -30,7 +28,7 @@
 /* Module Setup */
 /****************/
 
-#define H5F_PACKAGE		/*suppress error about including H5Fpkg	  */
+#include "H5Fmodule.h"          /* This source code file is part of the H5F module */
 
 
 /***********/
@@ -40,6 +38,7 @@
 #include "H5Eprivate.h"		/* Error handling		  	*/
 #include "H5Fpkg.h"             /* File access				*/
 #include "H5FDprivate.h"	/* File drivers				*/
+#include "H5MMprivate.h"	/* Memory management			*/
 #include "H5VMprivate.h"	/* Vectors and arrays 			*/
 
 
@@ -106,34 +105,32 @@ H5FL_BLK_DEFINE_STATIC(meta_accum);
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Jan 10 2008
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F__accum_read(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
+H5F__accum_read(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr,
     size_t size, void *buf/*out*/)
 {
-    H5FD_mem_t  map_type;               /* Mapped memory type */
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    H5FD_t *file;                       /* File driver pointer */
+    herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(fio_info);
-    HDassert(fio_info->f);
-    HDassert(fio_info->dxpl);
+    /* Sanity checks */
+    HDassert(f_sh);
     HDassert(buf);
 
-    /* Treat global heap as raw data */
-    map_type = (type == H5FD_MEM_GHEAP) ? H5FD_MEM_DRAW : type;
+    /* Translate to file driver I/O info object */
+    file = f_sh->lf;
 
     /* Check if this information is in the metadata accumulator */
-    if((fio_info->f->shared->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) && map_type != H5FD_MEM_DRAW) {
+    if((f_sh->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) && map_type != H5FD_MEM_DRAW) {
         H5F_meta_accum_t *accum;     /* Alias for file's metadata accumulator */
 
         /* Set up alias for file's metadata accumulator info */
-        accum = &fio_info->f->shared->accum;
+        accum = &f_sh->accum;
 
         if(size < H5F_ACCUM_MAX_SIZE) {
             /* Sanity check */
@@ -164,9 +161,9 @@ H5F__accum_read(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
 
                     /* Note the new buffer size */
                     accum->alloc_size = new_alloc_size;
-#ifdef H5_CLEAR_MEMORY
-    HDmemset(accum->buf + accum->size, 0, (accum->alloc_size - accum->size));
-#endif /* H5_CLEAR_MEMORY */
+
+                    /* Clear the memory */
+                    HDmemset(accum->buf + accum->size, 0, (accum->alloc_size - accum->size));
                 } /* end if */
 
                 /* Read the part before the metadata accumulator */
@@ -182,7 +179,7 @@ H5F__accum_read(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
                         accum->dirty_off += amount_before;
 
                     /* Dispatch to driver */
-                    if(H5FD_read(fio_info->f->shared->lf, fio_info->dxpl, map_type, addr, amount_before, accum->buf) < 0)
+                    if(H5FD_read(file, map_type, addr, amount_before, accum->buf) < 0)
                         HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed")
                 } /* end if */
                 else
@@ -196,12 +193,12 @@ H5F__accum_read(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
                     H5_CHECKED_ASSIGN(amount_after, size_t, ((addr + size) - (accum->loc + accum->size)), hsize_t);
 
                     /* Dispatch to driver */
-                    if(H5FD_read(fio_info->f->shared->lf, fio_info->dxpl, map_type, (accum->loc + accum->size), amount_after, (accum->buf + accum->size + amount_before)) < 0)
+                    if(H5FD_read(file, map_type, (accum->loc + accum->size), amount_after, (accum->buf + accum->size + amount_before)) < 0)
                         HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed")
                 } /* end if */
 
                 /* Copy the data out of the buffer */
-                HDmemcpy(buf, accum->buf + (addr - new_addr), size);
+                H5MM_memcpy(buf, accum->buf + (addr - new_addr), size);
 
                 /* Adjust the accumulator address & size */
                 accum->loc = new_addr;
@@ -210,13 +207,13 @@ H5F__accum_read(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
             /* Current read doesn't overlap with metadata accumulator, read it from file */
             else {
                 /* Dispatch to driver */
-                if(H5FD_read(fio_info->f->shared->lf, fio_info->dxpl, map_type, addr, size, buf) < 0)
+                if(H5FD_read(file, map_type, addr, size, buf) < 0)
                     HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed")
             } /* end else */
         } /* end if */
         else {
             /* Read the data */
-            if(H5FD_read(fio_info->f->shared->lf, fio_info->dxpl, map_type, addr, size, buf) < 0)
+            if(H5FD_read(file, map_type, addr, size, buf) < 0)
                 HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed")
 
             /* Check for overlap w/dirty accumulator */
@@ -253,13 +250,13 @@ H5F__accum_read(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
                 } /* end else */
 
                 /* Copy the dirty region to buffer */
-                HDmemcpy((unsigned char *)buf + buf_off, (unsigned char *)accum->buf + accum->dirty_off + dirty_off, overlap_size);
+                H5MM_memcpy((unsigned char *)buf + buf_off, (unsigned char *)accum->buf + accum->dirty_off + dirty_off, overlap_size);
             } /* end if */
         } /* end else */
     } /* end if */
     else {
         /* Read the data */
-        if(H5FD_read(fio_info->f->shared->lf, fio_info->dxpl, map_type, addr, size, buf) < 0)
+        if(H5FD_read(file, map_type, addr, size, buf) < 0)
             HGOTO_ERROR(H5E_IO, H5E_READERROR, FAIL, "driver read request failed")
     } /* end else */
 
@@ -276,13 +273,12 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Jun 11 2009
  *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5F__accum_adjust(H5F_meta_accum_t *accum, const H5F_io_info_t *fio_info,
+H5F__accum_adjust(H5F_meta_accum_t *accum, H5FD_t *file,
     H5F_accum_adjust_t adjust, size_t size)
 {
     herr_t      ret_value = SUCCEED;    /* Return value */
@@ -290,7 +286,7 @@ H5F__accum_adjust(H5F_meta_accum_t *accum, const H5F_io_info_t *fio_info,
     FUNC_ENTER_STATIC
 
     HDassert(accum);
-    HDassert(fio_info);
+    HDassert(file);
     HDassert(H5F_ACCUM_APPEND == adjust || H5F_ACCUM_PREPEND == adjust);
     HDassert(size > 0);
     HDassert(size <= H5F_ACCUM_MAX_SIZE);
@@ -348,7 +344,7 @@ H5F__accum_adjust(H5F_meta_accum_t *accum, const H5F_io_info_t *fio_info,
                     /* Check if the dirty region overlaps the region to eliminate from the accumulator */
                     if((accum->size - shrink_size) < (accum->dirty_off + accum->dirty_len)) {
                         /* Write out the dirty region from the metadata accumulator, with dispatch to driver */
-                        if(H5FD_write(fio_info->f->shared->lf, fio_info->dxpl, H5FD_MEM_DEFAULT, (accum->loc + accum->dirty_off), accum->dirty_len, (accum->buf + accum->dirty_off)) < 0)
+                        if(H5FD_write(file, H5FD_MEM_DEFAULT, (accum->loc + accum->dirty_off), accum->dirty_len, (accum->buf + accum->dirty_off)) < 0)
                             HGOTO_ERROR(H5E_FILE, H5E_WRITEERROR, FAIL, "file write failed")
 
                         /* Reset accumulator dirty flag */
@@ -359,7 +355,7 @@ H5F__accum_adjust(H5F_meta_accum_t *accum, const H5F_io_info_t *fio_info,
                     /* Check if the dirty region overlaps the region to eliminate from the accumulator */
                     if(shrink_size > accum->dirty_off) {
                         /* Write out the dirty region from the metadata accumulator, with dispatch to driver */
-                        if(H5FD_write(fio_info->f->shared->lf, fio_info->dxpl, H5FD_MEM_DEFAULT, (accum->loc + accum->dirty_off), accum->dirty_len, (accum->buf + accum->dirty_off)) < 0)
+                        if(H5FD_write(file, H5FD_MEM_DEFAULT, (accum->loc + accum->dirty_off), accum->dirty_len, (accum->buf + accum->dirty_off)) < 0)
                             HGOTO_ERROR(H5E_FILE, H5E_WRITEERROR, FAIL, "file write failed")
 
                         /* Reset accumulator dirty flag */
@@ -373,9 +369,9 @@ H5F__accum_adjust(H5F_meta_accum_t *accum, const H5F_io_info_t *fio_info,
 
             /* Trim the accumulator's use of its buffer */
             accum->size = remnant_size;
-            
+
             /* When appending, need to adjust location of accumulator */
-            if (H5F_ACCUM_APPEND == adjust) {
+            if(H5F_ACCUM_APPEND == adjust) {
                 /* Move remnant of accumulator down */
                 HDmemmove(accum->buf, (accum->buf + shrink_size), remnant_size);
 
@@ -395,9 +391,9 @@ H5F__accum_adjust(H5F_meta_accum_t *accum, const H5F_io_info_t *fio_info,
             /* Update accumulator info */
             accum->buf = new_buf;
             accum->alloc_size = new_size;
-#ifdef H5_CLEAR_MEMORY
-HDmemset(accum->buf + accum->size, 0, (accum->alloc_size - (accum->size + size)));
-#endif /* H5_CLEAR_MEMORY */
+
+            /* Clear the memory */
+            HDmemset(accum->buf + accum->size, 0, (accum->alloc_size - (accum->size + size)));
         } /* end if */
     } /* end if */
 
@@ -415,35 +411,33 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Jan 10 2008
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F__accum_write(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
+H5F__accum_write(H5F_shared_t *f_sh, H5FD_mem_t map_type, haddr_t addr,
     size_t size, const void *buf)
 {
-    H5FD_mem_t  map_type;               /* Mapped memory type */
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    H5FD_t *file;                       /* File driver pointer */
+    herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(fio_info);
-    HDassert(fio_info->f);
-    HDassert(H5F_INTENT(fio_info->f) & H5F_ACC_RDWR);
-    HDassert(fio_info->dxpl);
+    /* Sanity checks */
+    HDassert(f_sh);
+    HDassert(H5F_SHARED_INTENT(f_sh) & H5F_ACC_RDWR);
     HDassert(buf);
 
-    /* Treat global heap as raw data */
-    map_type = (type == H5FD_MEM_GHEAP) ? H5FD_MEM_DRAW : type;
+    /* Translate to file driver pointer */
+    file = f_sh->lf;
 
     /* Check for accumulating metadata */
-    if((fio_info->f->shared->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) && map_type != H5FD_MEM_DRAW) {
+    if((f_sh->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) && map_type != H5FD_MEM_DRAW) {
         H5F_meta_accum_t *accum;     /* Alias for file's metadata accumulator */
 
         /* Set up alias for file's metadata accumulator info */
-        accum = &fio_info->f->shared->accum;
+        accum = &f_sh->accum;
 
         if(size < H5F_ACCUM_MAX_SIZE) {
             /* Sanity check */
@@ -454,14 +448,14 @@ H5F__accum_write(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
                 /* Check if the new metadata adjoins the beginning of the current accumulator */
                 if((addr + size) == accum->loc) {
                     /* Check if we need to adjust accumulator size */
-                    if(H5F__accum_adjust(accum, fio_info, H5F_ACCUM_PREPEND, size) < 0)
+                    if(H5F__accum_adjust(accum, file, H5F_ACCUM_PREPEND, size) < 0)
                         HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator")
 
                     /* Move the existing metadata to the proper location */
                     HDmemmove(accum->buf + size, accum->buf, accum->size);
 
                     /* Copy the new metadata at the front */
-                    HDmemcpy(accum->buf, buf, size);
+                    H5MM_memcpy(accum->buf, buf, size);
 
                     /* Set the new size & location of the metadata accumulator */
                     accum->loc = addr;
@@ -479,11 +473,11 @@ H5F__accum_write(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
                 /* Check if the new metadata adjoins the end of the current accumulator */
                 else if(addr == (accum->loc + accum->size)) {
                     /* Check if we need to adjust accumulator size */
-                    if(H5F__accum_adjust(accum, fio_info, H5F_ACCUM_APPEND, size) < 0)
+                    if(H5F__accum_adjust(accum, file, H5F_ACCUM_APPEND, size) < 0)
                         HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator")
 
                     /* Copy the new metadata to the end */
-                    HDmemcpy(accum->buf + accum->size, buf, size);
+                    H5MM_memcpy(accum->buf + accum->size, buf, size);
 
                     /* Adjust the dirty region and mark accumulator dirty */
                     if(accum->dirty)
@@ -506,7 +500,7 @@ H5F__accum_write(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
                         size_t dirty_off = (size_t)(addr - accum->loc);
 
                         /* Copy the new metadata to the proper location within the accumulator */
-                        HDmemcpy(accum->buf + dirty_off, buf, size);
+                        H5MM_memcpy(accum->buf + dirty_off, buf, size);
 
                         /* Adjust the dirty region and mark accumulator dirty */
                         if(accum->dirty) {
@@ -539,7 +533,7 @@ H5F__accum_write(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
                         H5_CHECKED_ASSIGN(add_size, size_t, (accum->loc - addr), hsize_t);
 
                         /* Check if we need to adjust accumulator size */
-                        if(H5F__accum_adjust(accum, fio_info, H5F_ACCUM_PREPEND, add_size) < 0)
+                        if(H5F__accum_adjust(accum, file, H5F_ACCUM_PREPEND, add_size) < 0)
                             HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator")
 
                         /* Calculate the proper offset of the existing metadata */
@@ -549,7 +543,7 @@ H5F__accum_write(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
                         HDmemmove(accum->buf + size, accum->buf + old_offset, (accum->size - old_offset));
 
                         /* Copy the new metadata at the front */
-                        HDmemcpy(accum->buf, buf, size);
+                        H5MM_memcpy(accum->buf, buf, size);
 
                         /* Set the new size & location of the metadata accumulator */
                         accum->loc = addr;
@@ -579,14 +573,14 @@ H5F__accum_write(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
                         H5_CHECKED_ASSIGN(add_size, size_t, (addr + size) - (accum->loc + accum->size), hsize_t);
 
                         /* Check if we need to adjust accumulator size */
-                        if(H5F__accum_adjust(accum, fio_info, H5F_ACCUM_APPEND, add_size) < 0)
+                        if(H5F__accum_adjust(accum, file, H5F_ACCUM_APPEND, add_size) < 0)
                             HGOTO_ERROR(H5E_IO, H5E_CANTRESIZE, FAIL, "can't adjust metadata accumulator")
 
                         /* Compute offset of dirty region (after adjusting accumulator) */
                         dirty_off = (size_t)(addr - accum->loc);
 
                         /* Copy the new metadata to the end */
-                        HDmemcpy(accum->buf + dirty_off, buf, size);
+                        H5MM_memcpy(accum->buf + dirty_off, buf, size);
 
                         /* Set the new size of the metadata accumulator */
                         accum->size += add_size;
@@ -623,13 +617,13 @@ H5F__accum_write(const H5F_io_info_t *fio_info, H5FD_mem_t type, haddr_t addr,
 
                             /* Note the new buffer size */
                             accum->alloc_size = new_alloc_size;
-#ifdef H5_CLEAR_MEMORY
-HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
-#endif /* H5_CLEAR_MEMORY */
+
+                            /* Clear the memory */
+                            HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
                         } /* end if */
 
                         /* Copy the new metadata to the buffer */
-                        HDmemcpy(accum->buf, buf, size);
+                        H5MM_memcpy(accum->buf, buf, size);
 
                         /* Set the new size & location of the metadata accumulator */
                         accum->loc = addr;
@@ -645,7 +639,7 @@ HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
                 else {
                     /* Write out the existing metadata accumulator, with dispatch to driver */
                     if(accum->dirty) {
-                        if(H5FD_write(fio_info->f->shared->lf, fio_info->dxpl, H5FD_MEM_DEFAULT, accum->loc + accum->dirty_off, accum->dirty_len, accum->buf + accum->dirty_off) < 0)
+                        if(H5FD_write(file, H5FD_MEM_DEFAULT, accum->loc + accum->dirty_off, accum->dirty_len, accum->buf + accum->dirty_off) < 0)
                             HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
 
                         /* Reset accumulator dirty flag */
@@ -656,6 +650,7 @@ HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
                     /* Check if we need to resize the buffer */
                     if(size > accum->alloc_size) {
                         size_t new_size;        /* New size of accumulator */
+                        size_t clear_size;      /* Size of memory that needs clearing */
 
                         /* Adjust the buffer size to be a power of 2 that is large enough to hold data */
                         new_size = (size_t)1 << (1 + H5VM_log2_gen((uint64_t)(size - 1)));
@@ -666,12 +661,10 @@ HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
 
                         /* Note the new buffer size */
                         accum->alloc_size = new_size;
-#ifdef H5_CLEAR_MEMORY
-{
-size_t clear_size = MAX(accum->size, size);
-HDmemset(accum->buf + clear_size, 0, (accum->alloc_size - clear_size));
-}
-#endif /* H5_CLEAR_MEMORY */
+
+                        /* Clear the memory */
+                        clear_size = MAX(accum->size, size);
+                        HDmemset(accum->buf + clear_size, 0, (accum->alloc_size - clear_size));
                     } /* end if */
                     else {
                         /* Check if we should shrink the accumulator buffer */
@@ -693,7 +686,7 @@ HDmemset(accum->buf + clear_size, 0, (accum->alloc_size - clear_size));
                     accum->size = size;
 
                     /* Store the piece of metadata in the accumulator */
-                    HDmemcpy(accum->buf, buf, size);
+                    H5MM_memcpy(accum->buf, buf, size);
 
                     /* Adjust the dirty region and mark accumulator dirty */
                     accum->dirty_off = 0;
@@ -716,9 +709,9 @@ HDmemset(accum->buf + clear_size, 0, (accum->alloc_size - clear_size));
 
                     /* Note the new buffer size */
                     accum->alloc_size = new_size;
-#ifdef H5_CLEAR_MEMORY
-HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
-#endif /* H5_CLEAR_MEMORY */
+
+                    /* Clear the memory */
+                    HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
                 } /* end if */
 
                 /* Update the metadata accumulator information */
@@ -726,7 +719,7 @@ HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
                 accum->size = size;
 
                 /* Store the piece of metadata in the accumulator */
-                HDmemcpy(accum->buf, buf, size);
+                H5MM_memcpy(accum->buf, buf, size);
 
                 /* Adjust the dirty region and mark accumulator dirty */
                 accum->dirty_off = 0;
@@ -735,8 +728,14 @@ HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
             } /* end else */
         } /* end if */
         else {
+            /* Make certain that data in accumulator is visible before new write */
+	    if((H5F_SHARED_INTENT(f_sh) & H5F_ACC_SWMR_WRITE) > 0)
+                /* Flush if dirty and reset accumulator */
+                if(H5F__accum_reset(f_sh, TRUE) < 0)
+                    HGOTO_ERROR(H5E_IO, H5E_CANTRESET, FAIL, "can't reset accumulator")
+
             /* Write the data */
-            if(H5FD_write(fio_info->f->shared->lf, fio_info->dxpl, map_type, addr, size, buf) < 0)
+            if(H5FD_write(file, map_type, addr, size, buf) < 0)
                 HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
 
             /* Check for overlap w/accumulator */
@@ -781,7 +780,7 @@ HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
                     } /* end if */
                     else {        /* Access covers whole accumulator */
                         /* Reset accumulator, but don't flush */
-                        if(H5F__accum_reset(fio_info, FALSE) < 0)
+                        if(H5F__accum_reset(f_sh, FALSE) < 0)
                             HGOTO_ERROR(H5E_IO, H5E_CANTRESET, FAIL, "can't reset accumulator")
                     } /* end else */
                 } /* end if */
@@ -821,7 +820,7 @@ HDmemset(accum->buf + size, 0, (accum->alloc_size - size));
     } /* end if */
     else {
         /* Write the data */
-        if(H5FD_write(fio_info->f->shared->lf, fio_info->dxpl, map_type, addr, size, buf) < 0)
+        if(H5FD_write(file, map_type, addr, size, buf) < 0)
             HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
     } /* end else */
 
@@ -839,30 +838,31 @@ done:
  * Return:      Non-negative on success/Negative on failure
  *
  * Programmer:  Quincey Koziol
- *              koziol@hdfgroup.org
  *              Jan 10 2008
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F__accum_free(const H5F_io_info_t *fio_info, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr,
+H5F__accum_free(H5F_shared_t *f_sh, H5FD_mem_t H5_ATTR_UNUSED type, haddr_t addr,
     hsize_t size)
 {
     H5F_meta_accum_t *accum;            /* Alias for file's metadata accumulator */
+    H5FD_t *file;                       /* File driver pointer */
     herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* check arguments */
-    HDassert(fio_info);
-    HDassert(fio_info->f);
-    HDassert(fio_info->dxpl);
+    HDassert(f_sh);
 
     /* Set up alias for file's metadata accumulator info */
-    accum = &fio_info->f->shared->accum;
+    accum = &f_sh->accum;
+
+    /* Translate to file driver pointer */
+    file = f_sh->lf;
 
     /* Adjust the metadata accumulator to remove the freed block, if it overlaps */
-    if((fio_info->f->shared->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA)
+    if((f_sh->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA)
             && H5F_addr_overlap(addr, size, accum->loc, accum->size)) {
         size_t overlap_size;        /* Size of overlap with accumulator */
 
@@ -933,7 +933,7 @@ H5F__accum_free(const H5F_io_info_t *fio_info, H5FD_mem_t H5_ATTR_UNUSED type, h
                     /* Check if block to free is entirely before dirty region */
                     if(H5F_addr_le(tail_addr, dirty_start)) {
                         /* Write out the entire dirty region of the accumulator */
-                        if(H5FD_write(fio_info->f->shared->lf, fio_info->dxpl, H5FD_MEM_DEFAULT, dirty_start, accum->dirty_len, accum->buf + accum->dirty_off) < 0)
+                        if(H5FD_write(file, H5FD_MEM_DEFAULT, dirty_start, accum->dirty_len, accum->buf + accum->dirty_off) < 0)
                             HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
                     } /* end if */
                     /* Block to free overlaps with some/all of dirty region */
@@ -948,7 +948,7 @@ H5F__accum_free(const H5F_io_info_t *fio_info, H5FD_mem_t H5_ATTR_UNUSED type, h
                         HDassert(write_size > 0);
 
                         /* Write out the unfreed dirty region of the accumulator */
-                        if(H5FD_write(fio_info->f->shared->lf, fio_info->dxpl, H5FD_MEM_DEFAULT, dirty_start + dirty_delta, write_size, accum->buf + accum->dirty_off + dirty_delta) < 0)
+                        if(H5FD_write(file, H5FD_MEM_DEFAULT, dirty_start + dirty_delta, write_size, accum->buf + accum->dirty_off + dirty_delta) < 0)
                             HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
                     } /* end if */
 
@@ -968,7 +968,7 @@ H5F__accum_free(const H5F_io_info_t *fio_info, H5FD_mem_t H5_ATTR_UNUSED type, h
                         HDassert(write_size > 0);
 
                         /* Write out the unfreed end of the dirty region of the accumulator */
-                        if(H5FD_write(fio_info->f->shared->lf, fio_info->dxpl, H5FD_MEM_DEFAULT, dirty_start + dirty_delta, write_size, accum->buf + accum->dirty_off + dirty_delta) < 0)
+                        if(H5FD_write(file, H5FD_MEM_DEFAULT, dirty_start + dirty_delta, write_size, accum->buf + accum->dirty_off + dirty_delta) < 0)
                             HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
                     } /* end if */
 
@@ -1003,30 +1003,33 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Jan 10 2008
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F__accum_flush(const H5F_io_info_t *fio_info)
+H5F__accum_flush(H5F_shared_t *f_sh)
 {
     herr_t      ret_value = SUCCEED;    /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(fio_info);
-    HDassert(fio_info->f);
-    HDassert(fio_info->dxpl);
+    /* Sanity checks */
+    HDassert(f_sh);
 
     /* Check if we need to flush out the metadata accumulator */
-    if((fio_info->f->shared->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) && fio_info->f->shared->accum.dirty) {
+    if((f_sh->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) && f_sh->accum.dirty) {
+        H5FD_t *file;                       /* File driver pointer */
+
+        /* Translate to file driver pointer */
+        file = f_sh->lf;
+
         /* Flush the metadata contents */
-        if(H5FD_write(fio_info->f->shared->lf, fio_info->dxpl, H5FD_MEM_DEFAULT, fio_info->f->shared->accum.loc + fio_info->f->shared->accum.dirty_off, fio_info->f->shared->accum.dirty_len, fio_info->f->shared->accum.buf + fio_info->f->shared->accum.dirty_off) < 0)
+        if(H5FD_write(file, H5FD_MEM_DEFAULT, f_sh->accum.loc + f_sh->accum.dirty_off, f_sh->accum.dirty_len, f_sh->accum.buf + f_sh->accum.dirty_off) < 0)
             HGOTO_ERROR(H5E_IO, H5E_WRITEERROR, FAIL, "file write failed")
 
         /* Reset the dirty flag */
-        fio_info->f->shared->accum.dirty = FALSE;
+        f_sh->accum.dirty = FALSE;
     } /* end if */
 
 done:
@@ -1042,41 +1045,36 @@ done:
  * Return:	Non-negative on success/Negative on failure
  *
  * Programmer:	Quincey Koziol
- *		koziol@hdfgroup.org
  *		Jan 10 2008
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F__accum_reset(const H5F_io_info_t *fio_info, hbool_t flush)
+H5F__accum_reset(H5F_shared_t *f_sh, hbool_t flush)
 {
     herr_t      ret_value = SUCCEED;    /* Return value */
 
     FUNC_ENTER_PACKAGE
 
-    HDassert(fio_info);
-    HDassert(fio_info->f);
-    HDassert(fio_info->dxpl);
+    /* Sanity checks */
+    HDassert(f_sh);
 
     /* Flush any dirty data in accumulator, if requested */
     if(flush)
-        if(H5F__accum_flush(fio_info) < 0)
+        if(H5F__accum_flush(f_sh) < 0)
             HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "can't flush metadata accumulator")
 
     /* Check if we need to reset the metadata accumulator information */
-    if(fio_info->f->shared->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) {
-        /* Sanity check */
-        HDassert(!fio_info->f->closing || FALSE == fio_info->f->shared->accum.dirty);
-
+    if(f_sh->feature_flags & H5FD_FEAT_ACCUMULATE_METADATA) {
         /* Free the buffer */
-        if(fio_info->f->shared->accum.buf)
-            fio_info->f->shared->accum.buf = H5FL_BLK_FREE(meta_accum, fio_info->f->shared->accum.buf);
+        if(f_sh->accum.buf)
+            f_sh->accum.buf = H5FL_BLK_FREE(meta_accum, f_sh->accum.buf);
 
         /* Reset the buffer sizes & location */
-        fio_info->f->shared->accum.alloc_size = fio_info->f->shared->accum.size = 0;
-        fio_info->f->shared->accum.loc = HADDR_UNDEF;
-        fio_info->f->shared->accum.dirty = FALSE;
-        fio_info->f->shared->accum.dirty_len = 0;
+        f_sh->accum.alloc_size = f_sh->accum.size = 0;
+        f_sh->accum.loc = HADDR_UNDEF;
+        f_sh->accum.dirty = FALSE;
+        f_sh->accum.dirty_len = 0;
     } /* end if */
 
 done:
