@@ -12,81 +12,81 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:	Robb Matzke <matzke@llnl.gov>
- *		Wednesday, April 15, 1998
+ * Programmer:  Robb Matzke
+ *              Wednesday, April 15, 1998
  *
- * Purpose:	Data filter pipeline message.
+ * Purpose:     Data filter pipeline message.
  */
 
 #include "H5Omodule.h"          /* This source code file is part of the H5O module */
-#define H5Z_FRIEND		/*suppress error about including H5Zpkg	  */
+#define H5Z_FRIEND              /*suppress error about including H5Zpkg      */
 
 
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Dprivate.h"		/* Datasets				*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5FLprivate.h"	/* Free Lists				*/
-#include "H5MMprivate.h"	/* Memory management			*/
-#include "H5Opkg.h"             /* Object headers			*/
-#include "H5Zpkg.h"		/* Data filters				*/
+#include "H5private.h"          /* Generic Functions            */
+#include "H5Dprivate.h"         /* Datasets                     */
+#include "H5Eprivate.h"         /* Error handling               */
+#include "H5FLprivate.h"        /* Free Lists                   */
+#include "H5MMprivate.h"        /* Memory management            */
+#include "H5Opkg.h"             /* Object headers               */
+#include "H5Zpkg.h"             /* Data filters                 */
 
 
 /* PRIVATE PROTOTYPES */
 static herr_t H5O_pline_encode(H5F_t *f, uint8_t *p, const void *mesg);
-static void *H5O_pline_decode(H5F_t *f, hid_t dxpl_id, H5O_t *open_oh,
-    unsigned mesg_flags, unsigned *ioflags, size_t p_size, const uint8_t *p);
+static void *H5O__pline_decode(H5F_t *f, H5O_t *open_oh, unsigned mesg_flags,
+    unsigned *ioflags, size_t p_size, const uint8_t *p);
 static void *H5O_pline_copy(const void *_mesg, void *_dest);
 static size_t H5O_pline_size(const H5F_t *f, const void *_mesg);
-static herr_t H5O_pline_reset(void *_mesg);
-static herr_t H5O_pline_free(void *_mesg);
+static herr_t H5O__pline_reset(void *_mesg);
+static herr_t H5O__pline_free(void *_mesg);
 static herr_t H5O_pline_pre_copy_file(H5F_t *file_src,
     const void *mesg_src, hbool_t *deleted, const H5O_copy_t *cpy_info, void *_udata);
-static herr_t H5O_pline_debug(H5F_t *f, hid_t dxpl_id, const void *_mesg,
-    FILE * stream, int indent, int fwidth);
+static herr_t H5O__pline_debug(H5F_t *f, const void *_mesg, FILE * stream,
+    int indent, int fwidth);
 
 /* Set up & include shared message "interface" info */
-#define H5O_SHARED_TYPE			H5O_MSG_PLINE
-#define H5O_SHARED_DECODE		H5O_pline_shared_decode
-#define H5O_SHARED_DECODE_REAL		H5O_pline_decode
-#define H5O_SHARED_ENCODE		H5O_pline_shared_encode
-#define H5O_SHARED_ENCODE_REAL		H5O_pline_encode
-#define H5O_SHARED_SIZE			H5O_pline_shared_size
-#define H5O_SHARED_SIZE_REAL		H5O_pline_size
-#define H5O_SHARED_DELETE		H5O_pline_shared_delete
+#define H5O_SHARED_TYPE                 H5O_MSG_PLINE
+#define H5O_SHARED_DECODE               H5O_pline_shared_decode
+#define H5O_SHARED_DECODE_REAL          H5O__pline_decode
+#define H5O_SHARED_ENCODE               H5O_pline_shared_encode
+#define H5O_SHARED_ENCODE_REAL          H5O_pline_encode
+#define H5O_SHARED_SIZE                 H5O_pline_shared_size
+#define H5O_SHARED_SIZE_REAL            H5O_pline_size
+#define H5O_SHARED_DELETE               H5O__pline_shared_delete
 #undef H5O_SHARED_DELETE_REAL
-#define H5O_SHARED_LINK			H5O_pline_shared_link
+#define H5O_SHARED_LINK                 H5O__pline_shared_link
 #undef H5O_SHARED_LINK_REAL
-#define H5O_SHARED_COPY_FILE		H5O_pline_shared_copy_file
+#define H5O_SHARED_COPY_FILE            H5O__pline_shared_copy_file
 #undef H5O_SHARED_COPY_FILE_REAL
-#define H5O_SHARED_POST_COPY_FILE	H5O_pline_shared_post_copy_file
+#define H5O_SHARED_POST_COPY_FILE       H5O_pline_shared_post_copy_file
 #undef H5O_SHARED_POST_COPY_FILE_REAL
 #undef  H5O_SHARED_POST_COPY_FILE_UPD
-#define H5O_SHARED_DEBUG		H5O_pline_shared_debug
-#define H5O_SHARED_DEBUG_REAL		H5O_pline_debug
-#include "H5Oshared.h"			/* Shared Object Header Message Callbacks */
+#define H5O_SHARED_DEBUG                H5O_pline_shared_debug
+#define H5O_SHARED_DEBUG_REAL           H5O__pline_debug
+#include "H5Oshared.h"                  /* Shared Object Header Message Callbacks */
 
 /* This message derives from H5O message class */
 const H5O_msg_class_t H5O_MSG_PLINE[1] = {{
-    H5O_PLINE_ID,		/* message id number		*/
-    "filter pipeline",		/* message name for debugging	*/
-    sizeof(H5O_pline_t),	/* native message size		*/
-    H5O_SHARE_IS_SHARABLE|H5O_SHARE_IN_OHDR,	/* messages are sharable?       */
-    H5O_pline_shared_decode,	/* decode message		*/
-    H5O_pline_shared_encode,	/* encode message		*/
-    H5O_pline_copy,		/* copy the native value	*/
-    H5O_pline_shared_size,	/* size of raw message		*/
-    H5O_pline_reset,		/* reset method			*/
-    H5O_pline_free,		/* free method			*/
-    H5O_pline_shared_delete,    /* file delete method		*/
-    H5O_pline_shared_link,	/* link method			*/
-    NULL,			/* set share method		*/
-    NULL,		    	/*can share method		*/
-    H5O_pline_pre_copy_file,	/* pre copy native value to file */
-    H5O_pline_shared_copy_file,	/* copy native value to file    */
-    H5O_pline_shared_post_copy_file,	/* post copy native value to file    */
-    NULL,			/* get creation index		*/
-    NULL,			/* set creation index		*/
-    H5O_pline_shared_debug	/* debug the message		*/
+    H5O_PLINE_ID,        /* message id number        */
+    "filter pipeline",        /* message name for debugging    */
+    sizeof(H5O_pline_t),    /* native message size        */
+    H5O_SHARE_IS_SHARABLE|H5O_SHARE_IN_OHDR,    /* messages are sharable?       */
+    H5O_pline_shared_decode,    /* decode message        */
+    H5O_pline_shared_encode,    /* encode message        */
+    H5O_pline_copy,        /* copy the native value    */
+    H5O_pline_shared_size,    /* size of raw message        */
+    H5O__pline_reset,        /* reset method            */
+    H5O__pline_free,        /* free method            */
+    H5O__pline_shared_delete,   /* file delete method        */
+    H5O__pline_shared_link,    /* link method            */
+    NULL,            /* set share method        */
+    NULL,                /*can share method        */
+    H5O_pline_pre_copy_file,    /* pre copy native value to file */
+    H5O__pline_shared_copy_file,    /* copy native value to file    */
+    H5O_pline_shared_post_copy_file,    /* post copy native value to file    */
+    NULL,            /* get creation index        */
+    NULL,            /* set creation index        */
+    H5O_pline_shared_debug    /* debug the message        */
 }};
 
 /* Format version bounds for filter pipleline */
@@ -99,33 +99,33 @@ const unsigned H5O_pline_ver_bounds[] = {
 /* Declare a free list to manage the H5O_pline_t struct */
 H5FL_DEFINE(H5O_pline_t);
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_pline_decode
+ * Function:    H5O__pline_decode
  *
- * Purpose:	Decodes a filter pipeline message.
+ * Purpose:     Decodes a filter pipeline message.
  *
- * Return:	Success:	Ptr to the native message.
- *		Failure:	NULL
+ * Return:      Success:    Ptr to the native message.
+ *              Failure:    NULL
  *
- * Programmer:	Robb Matzke
+ * Programmer:  Robb Matzke
  *              Wednesday, April 15, 1998
  *
  *-------------------------------------------------------------------------
  */
 static void *
-H5O_pline_decode(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t H5_ATTR_UNUSED *open_oh,
+H5O__pline_decode(H5F_t H5_ATTR_UNUSED *f, H5O_t H5_ATTR_UNUSED *open_oh,
     unsigned H5_ATTR_UNUSED mesg_flags, unsigned H5_ATTR_UNUSED *ioflags,
     size_t p_size, const uint8_t *p)
 {
-    H5O_pline_t		*pline = NULL;          /* Pipeline message */
+    H5O_pline_t        *pline = NULL;          /* Pipeline message */
     H5Z_filter_info_t   *filter;                /* Filter to decode */
-    size_t		name_length;            /* Length of filter name */
-    size_t		i;                      /* Local index variable */
+    size_t        name_length;            /* Length of filter name */
+    size_t        i;                      /* Local index variable */
     const uint8_t *p_end = p + p_size - 1;  /* End of the p buffer */
-    void		*ret_value = NULL;      /* Return value */
+    void        *ret_value = NULL;      /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_STATIC
 
     /* check args */
     HDassert(p);
@@ -203,7 +203,7 @@ H5O_pline_decode(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t H5
 
         /* Filter parameters */
         if(filter->cd_nelmts) {
-            size_t	j;              /* Local index variable */
+            size_t    j;              /* Local index variable */
 
             /* Allocate space for the client data elements, or use the internal buffer */
             if(filter->cd_nelmts > H5Z_COMMON_CD_VALUES) {
@@ -235,22 +235,22 @@ H5O_pline_decode(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, H5O_t H5
 
 done:
     if(NULL == ret_value && pline) {
-        H5O_pline_reset(pline);
-        H5O_pline_free(pline);
+        H5O__pline_reset(pline);
+        H5O__pline_free(pline);
     } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5O_pline_decode() */
+} /* end H5O__pline_decode() */
+
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_pline_encode
+ * Function:    H5O_pline_encode
  *
- * Purpose:	Encodes message MESG into buffer P.
+ * Purpose:    Encodes message MESG into buffer P.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
+ * Programmer:    Robb Matzke
  *              Wednesday, April 15, 1998
  *
  *-------------------------------------------------------------------------
@@ -258,9 +258,9 @@ done:
 static herr_t
 H5O_pline_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p/*out*/, const void *mesg)
 {
-    const H5O_pline_t	*pline = (const H5O_pline_t*)mesg;      /* Pipeline message to encode */
+    const H5O_pline_t    *pline = (const H5O_pline_t*)mesg;      /* Pipeline message to encode */
     const       H5Z_filter_info_t *filter;      /* Filter to encode */
-    size_t	i, j;                   /* Local index variables */
+    size_t    i, j;                   /* Local index variables */
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -272,21 +272,21 @@ H5O_pline_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p/*out*/, const void *mesg)
     *p++ = (uint8_t)pline->version;
     *p++ = (uint8_t)(pline->nused);
     if(pline->version == H5O_PLINE_VERSION_1) {
-        *p++ = 0;	/*reserved 1*/
-        *p++ = 0;	/*reserved 2*/
-        *p++ = 0;	/*reserved 3*/
-        *p++ = 0;	/*reserved 4*/
-        *p++ = 0;	/*reserved 5*/
-        *p++ = 0;	/*reserved 6*/
+        *p++ = 0;    /*reserved 1*/
+        *p++ = 0;    /*reserved 2*/
+        *p++ = 0;    /*reserved 3*/
+        *p++ = 0;    /*reserved 4*/
+        *p++ = 0;    /*reserved 5*/
+        *p++ = 0;    /*reserved 6*/
     } /* end if */
 
     /* Encode filters */
     for(i = 0, filter = &pline->filter[0]; i < pline->nused; i++, filter++) {
-        const char	*name;                  /* Filter name */
-        size_t		name_length;            /* Length of filter name */
+        const char    *name;                  /* Filter name */
+        size_t        name_length;            /* Length of filter name */
 
         /* Filter ID */
-	UINT16ENCODE(p, filter->id);
+        UINT16ENCODE(p, filter->id);
 
         /* Skip writing the name length & name if the filter is an internal filter */
         if(pline->version > H5O_PLINE_VERSION_1 && filter->id < H5Z_FILTER_RESERVED) {
@@ -294,7 +294,7 @@ H5O_pline_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p/*out*/, const void *mesg)
             name = NULL;
         } /* end if */
         else {
-            H5Z_class2_t	*cls;                   /* Filter class */
+            H5Z_class2_t    *cls;                   /* Filter class */
 
             /*
              * Get the filter name.  If the pipeline message has a name in it then
@@ -310,26 +310,26 @@ H5O_pline_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p/*out*/, const void *mesg)
         } /* end else */
 
         /* Filter flags */
-	UINT16ENCODE(p, filter->flags);
+        UINT16ENCODE(p, filter->flags);
 
         /* # of filter parameters */
-	UINT16ENCODE(p, filter->cd_nelmts);
+        UINT16ENCODE(p, filter->cd_nelmts);
 
         /* Encode name, if there is one to encode */
-	if(name_length > 0) {
+        if(name_length > 0) {
             /* Store name, with null terminator */
-	    HDmemcpy(p, name, name_length);
-	    p += name_length;
+            H5MM_memcpy(p, name, name_length);
+            p += name_length;
 
             /* Pad out name to alignment, in older versions */
             if(pline->version == H5O_PLINE_VERSION_1)
                 while(name_length++ % 8)
                     *p++ = 0;
-	} /* end if */
+        } /* end if */
 
         /* Filter parameters */
-	for(j = 0; j < filter->cd_nelmts; j++)
-	    UINT32ENCODE(p, filter->cd_values[j]);
+        for(j = 0; j < filter->cd_nelmts; j++)
+            UINT32ENCODE(p, filter->cd_values[j]);
 
         /* Align the parameters for older versions of the format */
         if(pline->version == H5O_PLINE_VERSION_1)
@@ -340,19 +340,19 @@ H5O_pline_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p/*out*/, const void *mesg)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5O_pline_encode() */
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_pline_copy
+ * Function:    H5O_pline_copy
  *
- * Purpose:	Copies a filter pipeline message from SRC to DST allocating
- *		DST if necessary.  If DST is already allocated then we assume
- *		that it isn't initialized.
+ * Purpose:    Copies a filter pipeline message from SRC to DST allocating
+ *        DST if necessary.  If DST is already allocated then we assume
+ *        that it isn't initialized.
  *
- * Return:	Success:	Ptr to DST or allocated result.
+ * Return:    Success:    Ptr to DST or allocated result.
  *
- *		Failure:	NULL
+ *        Failure:    NULL
  *
- * Programmer:	Robb Matzke
+ * Programmer:    Robb Matzke
  *              Wednesday, April 15, 1998
  *
  *-------------------------------------------------------------------------
@@ -360,16 +360,16 @@ H5O_pline_encode(H5F_t H5_ATTR_UNUSED *f, uint8_t *p/*out*/, const void *mesg)
 static void *
 H5O_pline_copy(const void *_src, void *_dst/*out*/)
 {
-    const H5O_pline_t	*src = (const H5O_pline_t *)_src;       /* Source pipeline message */
-    H5O_pline_t		*dst = (H5O_pline_t *)_dst;             /* Destination pipeline message */
-    size_t		i;                      /* Local index variable */
-    H5O_pline_t		*ret_value = NULL;      /* Return value */
+    const H5O_pline_t    *src = (const H5O_pline_t *)_src;       /* Source pipeline message */
+    H5O_pline_t        *dst = (H5O_pline_t *)_dst;             /* Destination pipeline message */
+    size_t        i;                      /* Local index variable */
+    H5O_pline_t        *ret_value = NULL;      /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
     /* Allocate pipeline message, if not provided */
     if(!dst && NULL == (dst = H5FL_MALLOC(H5O_pline_t)))
-	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
     /* Shallow copy basic fields */
     *dst = *src;
@@ -378,8 +378,8 @@ H5O_pline_copy(const void *_src, void *_dst/*out*/)
     dst->nalloc = dst->nused;
     if(dst->nalloc) {
         /* Allocate array to hold filters */
-	if(NULL == (dst->filter = (H5Z_filter_info_t *)H5MM_calloc(dst->nalloc * sizeof(dst->filter[0]))))
-	    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
+    if(NULL == (dst->filter = (H5Z_filter_info_t *)H5MM_calloc(dst->nalloc * sizeof(dst->filter[0]))))
+        HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
         /* Deep-copy filters */
         for(i = 0; i < src->nused; i++) {
@@ -409,7 +409,7 @@ H5O_pline_copy(const void *_src, void *_dst/*out*/)
                     if(NULL == (dst->filter[i].cd_values = (unsigned *)H5MM_malloc(src->filter[i].cd_nelmts* sizeof(unsigned))))
                         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
-                    HDmemcpy(dst->filter[i].cd_values, src->filter[i].cd_values,
+                    H5MM_memcpy(dst->filter[i].cd_values, src->filter[i].cd_values,
                             src->filter[i].cd_nelmts * sizeof(unsigned));
                 } /* end if */
                 else
@@ -418,32 +418,32 @@ H5O_pline_copy(const void *_src, void *_dst/*out*/)
         } /* end for */
     } /* end if */
     else
-	dst->filter = NULL;
+    dst->filter = NULL;
 
     /* Set return value */
     ret_value = dst;
 
 done:
     if(!ret_value && dst) {
-        H5O_pline_reset(dst);
-	if(!_dst)
-            H5O_pline_free(dst);
+        H5O__pline_reset(dst);
+        if(!_dst)
+            H5O__pline_free(dst);
     } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_pline_copy() */
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_pline_size
+ * Function:    H5O_pline_size
  *
- * Purpose:	Determines the size of a raw filter pipeline message.
+ * Purpose:    Determines the size of a raw filter pipeline message.
  *
- * Return:	Success:	Size of message.
+ * Return:    Success:    Size of message.
  *
- *		Failure:	zero
+ *        Failure:    zero
  *
- * Programmer:	Robb Matzke
+ * Programmer:    Robb Matzke
  *              Wednesday, April 15, 1998
  *
  *-------------------------------------------------------------------------
@@ -451,27 +451,27 @@ done:
 static size_t
 H5O_pline_size(const H5F_t H5_ATTR_UNUSED *f, const void *mesg)
 {
-    const H5O_pline_t	*pline = (const H5O_pline_t*)mesg;      /* Pipeline message */
+    const H5O_pline_t    *pline = (const H5O_pline_t*)mesg;      /* Pipeline message */
     size_t i;                   /* Local index variable */
     size_t ret_value = 0;       /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Message header */
-    ret_value = 1 +			/*version			*/
-	   1 +				/*number of filters		*/
-	   (pline->version == H5O_PLINE_VERSION_1 ? 6 : 0);	/*reserved			*/
+    ret_value = (size_t)(1 +        /*version            */
+                1 +                /*number of filters        */
+                (pline->version == H5O_PLINE_VERSION_1 ? 6 : 0));    /*reserved            */
 
     /* Calculate size of each filter in pipeline */
     for(i = 0; i < pline->nused; i++) {
-        size_t	name_len;               /* Length of filter name */
+        size_t    name_len;               /* Length of filter name */
         const char *name;               /* Filter name */
 
         /* Don't write the name length & name if the filter is an internal filter */
         if(pline->version > H5O_PLINE_VERSION_1 && pline->filter[i].id < H5Z_FILTER_RESERVED)
             name_len = 0;
         else {
-            H5Z_class2_t	*cls;                   /* Filter class */
+            H5Z_class2_t    *cls;                   /* Filter class */
 
             /* Get the name of the filter, same as done with H5O_pline_encode() */
             if(NULL == (name = pline->filter[i].name) && (cls = H5Z_find(pline->filter[i].id)))
@@ -479,13 +479,13 @@ H5O_pline_size(const H5F_t H5_ATTR_UNUSED *f, const void *mesg)
             name_len = name ? HDstrlen(name) + 1 : 0;
         } /* end else */
 
-	ret_value += 2 +			/*filter identification number	*/
-		(size_t)((pline->version == H5O_PLINE_VERSION_1 || pline->filter[i].id >= H5Z_FILTER_RESERVED) ? 2 : 0) +				/*name length			*/
-		2 +				/*flags				*/
-		2 +				/*number of client data values	*/
-		(pline->version == H5O_PLINE_VERSION_1 ? (size_t)H5O_ALIGN_OLD(name_len) : name_len);	/*length of the filter name	*/
+        ret_value += 2 +            /*filter identification number    */
+            (size_t)((pline->version == H5O_PLINE_VERSION_1 || pline->filter[i].id >= H5Z_FILTER_RESERVED) ? 2 : 0) +                /*name length            */
+            2 +                /*flags                */
+            2 +                /*number of client data values    */
+            (pline->version == H5O_PLINE_VERSION_1 ? (size_t)H5O_ALIGN_OLD(name_len) : name_len);    /*length of the filter name    */
 
-	ret_value += pline->filter[i].cd_nelmts * 4;
+        ret_value += pline->filter[i].cd_nelmts * 4;
         if(pline->version == H5O_PLINE_VERSION_1)
             if(pline->filter[i].cd_nelmts % 2)
                 ret_value += 4;
@@ -494,27 +494,27 @@ H5O_pline_size(const H5F_t H5_ATTR_UNUSED *f, const void *mesg)
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_pline_size() */
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_pline_reset
+ * Function:    H5O__pline_reset
  *
- * Purpose:	Resets a filter pipeline message by clearing all filters.
- *		The MESG buffer is not freed.
+ * Purpose:    Resets a filter pipeline message by clearing all filters.
+ *        The MESG buffer is not freed.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
+ * Programmer:    Robb Matzke
  *              Wednesday, April 15, 1998
  *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_pline_reset(void *mesg)
+H5O__pline_reset(void *mesg)
 {
-    H5O_pline_t	*pline = (H5O_pline_t*)mesg;    /* Pipeline message */
-    size_t	i;                              /* Local index variable */
+    H5O_pline_t    *pline = (H5O_pline_t*)mesg;    /* Pipeline message */
+    size_t    i;                              /* Local index variable */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* NOTE: This function can be called during error processing from
      *       other API calls so DO NOT ASSUME THAT ANY VALUES ARE SANE.
@@ -523,8 +523,7 @@ H5O_pline_reset(void *mesg)
     HDassert(pline);
 
     /* Free the filter information and array */
-    if (pline->filter) {
-
+    if(pline->filter) {
         /* Free information for each filter */
         for(i = 0; i < pline->nused; i++) {
             if(pline->filter[i].name && pline->filter[i].name != pline->filter[i]._name)
@@ -548,34 +547,34 @@ H5O_pline_reset(void *mesg)
     pline->version = H5O_PLINE_VERSION_1;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_pline_reset() */
+} /* end H5O__pline_reset() */
+
 
-
 /*-------------------------------------------------------------------------
- * Function:	H5O_pline_free
+ * Function:    H5O__pline_free
  *
- * Purpose:	Free's the message
+ * Purpose:    Frees the message
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:	Quincey Koziol
+ * Programmer:    Quincey Koziol
  *              Saturday, March 11, 2000
  *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_pline_free(void *mesg)
+H5O__pline_free(void *mesg)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     HDassert(mesg);
 
     mesg = H5FL_FREE(H5O_pline_t, mesg);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_pline_free() */
+} /* end H5O__pline_free() */
+
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O_pline_pre_copy_file
  *
@@ -623,29 +622,29 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_pline_pre_copy_file() */
 
-
+
 /*-------------------------------------------------------------------------
- * Function:	H5O_pline_debug
+ * Function:    H5O__pline_debug
  *
- * Purpose:	Prints debugging information for filter pipeline message MESG
- *		on output stream STREAM.  Each line is indented INDENT
- *		characters and the field name takes up FWIDTH characters.
+ * Purpose:    Prints debugging information for filter pipeline message MESG
+ *        on output stream STREAM.  Each line is indented INDENT
+ *        characters and the field name takes up FWIDTH characters.
  *
- * Return:	Non-negative on success/Negative on failure
+ * Return:    Non-negative on success/Negative on failure
  *
- * Programmer:	Robb Matzke
+ * Programmer:    Robb Matzke
  *              Wednesday, April 15, 1998
  *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_pline_debug(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, const void *mesg, FILE *stream,
-		int indent, int fwidth)
+H5O__pline_debug(H5F_t H5_ATTR_UNUSED *f, const void *mesg, FILE *stream,
+    int indent, int fwidth)
 {
-    const H5O_pline_t	*pline = (const H5O_pline_t *)mesg;
-    size_t		i, j;
+    const H5O_pline_t    *pline = (const H5O_pline_t *)mesg;
+    size_t        i, j;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* check args */
     HDassert(f);
@@ -655,48 +654,48 @@ H5O_pline_debug(H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, const voi
     HDassert(fwidth >= 0);
 
     HDfprintf(stream, "%*s%-*s %Zu/%Zu\n", indent, "", fwidth,
-	    "Number of filters:",
-	    pline->nused,
-	    pline->nalloc);
+        "Number of filters:",
+        pline->nused,
+        pline->nalloc);
 
     /* Loop over all the filters */
     for(i = 0; i < pline->nused; i++) {
-	char		name[32];
+        char        name[32];
 
-	HDsnprintf(name, sizeof(name), "Filter at position %u", (unsigned)i);
-	HDfprintf(stream, "%*s%-*s\n", indent, "", fwidth, name);
-	HDfprintf(stream, "%*s%-*s 0x%04x\n", indent + 3, "", MAX(0, fwidth - 3),
-		"Filter identification:",
-		(unsigned)(pline->filter[i].id));
-	if(pline->filter[i].name)
-	    HDfprintf(stream, "%*s%-*s \"%s\"\n", indent + 3, "", MAX(0, fwidth - 3),
-		    "Filter name:",
-		    pline->filter[i].name);
-	else
-	    HDfprintf(stream, "%*s%-*s NONE\n", indent + 3, "", MAX(0, fwidth - 3),
-		    "Filter name:");
-	HDfprintf(stream, "%*s%-*s 0x%04x\n", indent + 3, "", MAX(0, fwidth - 3),
-		"Flags:",
-		pline->filter[i].flags);
-	HDfprintf(stream, "%*s%-*s %Zu\n", indent + 3, "", MAX(0, fwidth - 3),
-		"Num CD values:",
-		pline->filter[i].cd_nelmts);
+        HDsnprintf(name, sizeof(name), "Filter at position %u", (unsigned)i);
+        HDfprintf(stream, "%*s%-*s\n", indent, "", fwidth, name);
+        HDfprintf(stream, "%*s%-*s 0x%04x\n", indent + 3, "", MAX(0, fwidth - 3),
+            "Filter identification:",
+            (unsigned)(pline->filter[i].id));
+        if(pline->filter[i].name)
+            HDfprintf(stream, "%*s%-*s \"%s\"\n", indent + 3, "", MAX(0, fwidth - 3),
+                "Filter name:",
+                pline->filter[i].name);
+        else
+            HDfprintf(stream, "%*s%-*s NONE\n", indent + 3, "", MAX(0, fwidth - 3),
+                "Filter name:");
+        HDfprintf(stream, "%*s%-*s 0x%04x\n", indent + 3, "", MAX(0, fwidth - 3),
+            "Flags:",
+            pline->filter[i].flags);
+        HDfprintf(stream, "%*s%-*s %Zu\n", indent + 3, "", MAX(0, fwidth - 3),
+            "Num CD values:",
+            pline->filter[i].cd_nelmts);
 
-        /* Filter parameters */
-	for(j = 0; j < pline->filter[i].cd_nelmts; j++) {
-	    char	field_name[32];
+            /* Filter parameters */
+        for(j = 0; j < pline->filter[i].cd_nelmts; j++) {
+            char    field_name[32];
 
-	    HDsnprintf(field_name, sizeof(field_name), "CD value %lu", (unsigned long)j);
-	    HDfprintf(stream, "%*s%-*s %u\n", indent + 6, "", MAX(0, fwidth - 6),
-		    field_name,
-		    pline->filter[i].cd_values[j]);
-	} /* end for */
+            HDsnprintf(field_name, sizeof(field_name), "CD value %lu", (unsigned long)j);
+            HDfprintf(stream, "%*s%-*s %u\n", indent + 6, "", MAX(0, fwidth - 6),
+                field_name,
+                pline->filter[i].cd_values[j]);
+        } /* end for */
     } /* end for */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5O_pline_debug() */
+} /* end H5O__pline_debug() */
+
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O_pline_set_version
  *
