@@ -12,14 +12,14 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke <matzke@llnl.gov>
+ * Programmer:  Robb Matzke
  *              Tuesday, June 16, 1998
  *
  * Purpose:	Tests functions in H5Tbit.c
  */
 #include "h5test.h"
 
-#define H5T_PACKAGE
+#define H5T_FRIEND		/*suppress error about including H5Tpkg	  */
 #include "H5Tpkg.h"
 
 #define NTESTS	100000
@@ -57,13 +57,13 @@ test_find (void)
     n = H5T__bit_find(v1, (size_t)0, (size_t)0, H5T_BIT_LSB, TRUE);
     if(-1 != n) {
 	H5_FAILED();
-	puts ("    Zero length test failed (lsb)!");
+	HDputs ("    Zero length test failed (lsb)!");
 	goto failed;
     }
     n = H5T__bit_find(v1, (size_t)0, (size_t)0, H5T_BIT_MSB, TRUE);
     if(-1 != n) {
 	H5_FAILED();
-	puts ("    Zero length test failed (msb)!");
+	HDputs ("    Zero length test failed (msb)!");
 	goto failed;
     }
 
@@ -73,30 +73,30 @@ test_find (void)
     n = H5T__bit_find(v1, (size_t)0, 8 * sizeof(v1), H5T_BIT_LSB, TRUE);
     if(-1 != n) {
 	H5_FAILED();
-	puts ("    Zero buffer test failed (lsb)!");
+	HDputs ("    Zero buffer test failed (lsb)!");
 	goto failed;
     }
     n = H5T__bit_find(v1, (size_t)0, 8 * sizeof(v1), H5T_BIT_MSB, TRUE);
     if(-1 != n) {
 	H5_FAILED();
-	puts ("    Zero buffer test failed (msb)!");
+	HDputs ("    Zero buffer test failed (msb)!");
 	goto failed;
     }
 
     /* Try all combinations of one byte */
     for(i = 0; i < 8 * (int)sizeof(v1); i++) {
 	HDmemset(v1, 0, sizeof v1);
-	v1[i / 8] = 1 << (i % 8);
+	v1[i / 8] = (uint8_t)(1 << (i % 8));
 	n = H5T__bit_find(v1, (size_t)0, 8 * sizeof(v1), H5T_BIT_LSB, TRUE);
 	if((ssize_t)i != n) {
 	    H5_FAILED();
-	    printf ("    Test for set bit %d failed (lsb)!\n", i);
+	    HDprintf ("    Test for set bit %d failed (lsb)!\n", i);
 	    goto failed;
 	}
 	n = H5T__bit_find(v1, (size_t)0, 8 * sizeof(v1), H5T_BIT_MSB, TRUE);
 	if((ssize_t)i != n) {
 	    H5_FAILED();
-	    printf ("    Test for set bit %d failed (msb)!\n", i);
+	    HDprintf ("    Test for set bit %d failed (msb)!\n", i);
 	    goto failed;
 	}
     }
@@ -106,30 +106,30 @@ test_find (void)
     n = H5T__bit_find(v1, (size_t)0, 8 * sizeof(v1), H5T_BIT_LSB, FALSE);
     if(-1 != n) {
 	H5_FAILED();
-	puts ("    One buffer test failed (lsb)!");
+	HDputs ("    One buffer test failed (lsb)!");
 	goto failed;
     }
     n = H5T__bit_find(v1, (size_t)0, 8 * sizeof(v1), H5T_BIT_MSB, FALSE);
     if(-1 != n) {
 	H5_FAILED();
-	puts ("    One buffer test failed (msb)!");
+	HDputs ("    One buffer test failed (msb)!");
 	goto failed;
     }
 
     /* Try all combinations of one byte */
     for (i=0; i<8*(int)sizeof(v1); i++) {
-	memset (v1, 0xff, sizeof v1);
-	v1[i/8] &= ~(1<<(i%8));
+	HDmemset(v1, 0xff, sizeof v1);
+	v1[i / 8] &= (uint8_t)~(1 << (i % 8));
 	n = H5T__bit_find (v1, (size_t)0, 8*sizeof(v1), H5T_BIT_LSB, FALSE);
 	if ((ssize_t)i!=n) {
 	    H5_FAILED();
-	    printf ("    Test for clear bit %d failed (lsb)!\n", i);
+	    HDprintf ("    Test for clear bit %d failed (lsb)!\n", i);
 	    goto failed;
 	}
 	n = H5T__bit_find (v1, (size_t)0, 8*sizeof(v1), H5T_BIT_MSB, FALSE);
 	if ((ssize_t)i!=n) {
 	    H5_FAILED();
-	    printf ("    Test for clear bit %d failed (lsb)!\n", i);
+	    HDprintf ("    Test for clear bit %d failed (lsb)!\n", i);
 	    goto failed;
 	}
     }
@@ -139,9 +139,9 @@ test_find (void)
     return 0;
 
  failed:
-    printf ("    v = 0x");
-    for (i=0; i<(int)sizeof(v1); i++) printf ("%02x", v1[i]);
-    printf ("\n");
+    HDprintf ("    v = 0x");
+    for (i=0; i<(int)sizeof(v1); i++) HDprintf ("%02x", v1[i]);
+    HDprintf ("\n");
     return -1;
 }
 
@@ -173,24 +173,24 @@ test_copy (void)
     TESTING("bit copy operations");
 
     for (i=0; i<NTESTS; i++) {
-	s_offset = HDrand() % (8*sizeof v1);
-	d_offset = HDrand() % (8*sizeof v2);
+	s_offset = (size_t)HDrand() % (8 * sizeof v1);
+	d_offset = (size_t)HDrand() % (8 * sizeof v2);
 	size = (unsigned)HDrand() % MIN (8*sizeof(v1), 8*sizeof(v2));
 	size = MIN3 (size, 8*sizeof(v1)-s_offset, 8*sizeof(v2)-d_offset);
-	memset (v1, 0xff, sizeof v1);
-	memset (v2, 0x00, sizeof v2);
+	HDmemset(v1, 0xff, sizeof v1);
+	HDmemset(v2, 0x00, sizeof v2);
 
 	/* Copy some bits to v2 and make sure something was copied */
 	H5T__bit_copy (v2, d_offset, v1, s_offset, size);
 	for (j=0; j<(int)sizeof(v2); j++) if (v2[j]) break;
 	if (size>0 && j>=(int)sizeof(v2)) {
 	    H5_FAILED();
-	    puts ("    Unabled to find copied region in destination");
+	    HDputs ("    Unabled to find copied region in destination");
 	    goto failed;
 	}
 	if (0==size && j<(int)sizeof(v2)) {
 	    H5_FAILED();
-	    puts ("    Found copied bits when we shouldn't have");
+	    HDputs ("    Found copied bits when we shouldn't have");
 	    goto failed;
 	}
 
@@ -199,25 +199,25 @@ test_copy (void)
 	n = H5T__bit_find (v2, (size_t)0, 8*sizeof(v2), H5T_BIT_LSB, 1);
 	if (size>0 && n!=(ssize_t)d_offset) {
 	    H5_FAILED();
-	    printf ("    Unable to find first copied bit in destination "
+	    HDprintf ("    Unable to find first copied bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (0==size && n>=0) {
 	    H5_FAILED();
-	    puts ("    Found copied bits and shouldn't have!");
+	    HDputs ("    Found copied bits and shouldn't have!");
 	    goto failed;
 	}
 	n = H5T__bit_find (v2, d_offset, 8*sizeof(v2)-d_offset, H5T_BIT_LSB, 0);
 	if (d_offset+size<8*sizeof(v2) && n!=(ssize_t)size) {
 	    H5_FAILED();
-	    printf ("    Unable to find last copied bit in destination "
+	    HDprintf ("    Unable to find last copied bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (d_offset+size==8*sizeof(v2) && n>=0) {
 	    H5_FAILED();
-	    puts ("    High-order zeros are present and shouldn't be!");
+	    HDputs ("    High-order zeros are present and shouldn't be!");
 	    goto failed;
 	}
 
@@ -228,25 +228,25 @@ test_copy (void)
 	n = H5T__bit_find (v2, (size_t)0, 8*sizeof(v2), H5T_BIT_MSB, 1);
 	if (size>0 && (size_t)(n+1)!=d_offset+size) {
 	    H5_FAILED();
-	    printf ("    Unable to find last copied bit in destination "
+	    HDprintf ("    Unable to find last copied bit in destination "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (0==size && n>=0) {
 	    H5_FAILED();
-	    puts ("    Found copied bits but shouldn't have (reverse)!");
+	    HDputs ("    Found copied bits but shouldn't have (reverse)!");
 	    goto failed;
 	}
 	n = H5T__bit_find (v2, (size_t)0, d_offset+size, H5T_BIT_MSB, 0);
 	if (d_offset>0 && n+1!=(ssize_t)d_offset) {
 	    H5_FAILED();
-	    printf ("    Unable to find beginning of copied data "
+	    HDprintf ("    Unable to find beginning of copied data "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (0==d_offset && n>=0) {
 	    H5_FAILED();
-	    puts ("    Found leading original data but shouldn't have!");
+	    HDputs ("    Found leading original data but shouldn't have!");
 	    goto failed;
 	}
 
@@ -256,14 +256,14 @@ test_copy (void)
     return 0;
 
  failed:
-    printf ("    i=%d, s_offset=%lu, d_offset=%lu, size=%lu\n",
+    HDprintf ("    i=%d, s_offset=%lu, d_offset=%lu, size=%lu\n",
 	    i, (unsigned long)s_offset, (unsigned long)d_offset,
 	    (unsigned long)size);
-    printf ("    s = 0x");
-    for (j=sizeof(v1)-1; j>=0; --j) printf ("%02x", v1[j]);
-    printf ("\n    d = 0x");
-    for (j=sizeof(v2)-1; j>=0; --j) printf ("%02x", v2[j]);
-    printf ("\n");
+    HDprintf ("    s = 0x");
+    for (j=sizeof(v1)-1; j>=0; --j) HDprintf ("%02x", v1[j]);
+    HDprintf ("\n    d = 0x");
+    for (j=sizeof(v2)-1; j>=0; --j) HDprintf ("%02x", v2[j]);
+    HDprintf ("\n");
     return -1;
 }
 
@@ -295,23 +295,23 @@ test_shift (void)
     TESTING("bit shift operations");
 
     for (i=0; i<NTESTS; i++) {
-	offset = HDrand() % (8*sizeof vector);
-	size = (unsigned)HDrand() % (8*sizeof(vector)-offset);
+	offset = (size_t)HDrand() % (8 * sizeof vector);
+	size = (size_t)HDrand() % (8 * sizeof(vector) - offset);
         /* Don't want size to be 0 */
         if(size == 0) continue;
-        shift_dist = HDrand() % size;
+        shift_dist = (ssize_t)((size_t)HDrand() % size);
 
 	/*-------- LEFT-shift some bits and make sure something was shifted --------*/
-	memset (vector, 0x00, sizeof vector);
+	HDmemset(vector, 0x00, sizeof vector);
         H5T__bit_set (vector, offset, size, 1);
 
         H5T__bit_shift (vector, shift_dist, offset, size);
 
 	/* Look for the ones */
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_LSB, 1);
-	if ((size_t)n!=offset+shift_dist) {
+	if(n != (ssize_t)offset + shift_dist) {
 	    H5_FAILED();
-	    printf ("    Unable to find first bit in destination "
+	    HDprintf ("    Unable to find first bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -323,13 +323,13 @@ test_shift (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_MSB, 1);
 	if (n!=(ssize_t)(offset+size-1)) {
 	    H5_FAILED();
-	    printf ("    Unable to find last bit in destination "
+	    HDprintf ("    Unable to find last bit in destination "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
 
 	/*-------- RIGHT-shift some bits and make sure something was shifted --------*/
-	memset (vector, 0x00, sizeof vector);
+	HDmemset(vector, 0x00, sizeof vector);
         H5T__bit_set (vector, offset, size, 1);
 
         H5T__bit_shift (vector, -shift_dist, offset, size);
@@ -338,7 +338,7 @@ test_shift (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_LSB, 1);
 	if ((size_t)n!=offset) {
 	    H5_FAILED();
-	    printf ("    Unable to find first bit in destination "
+	    HDprintf ("    Unable to find first bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -348,9 +348,9 @@ test_shift (void)
 	 * that reverse searches work as expected.
 	 */
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_MSB, 1);
-	if (n!=(ssize_t)(offset+size-shift_dist-1)) {
+	if(n != (ssize_t)(offset + size) - shift_dist - 1) {
 	    H5_FAILED();
-	    printf ("    Unable to find last bit in destination "
+	    HDprintf ("    Unable to find last bit in destination "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -360,11 +360,11 @@ test_shift (void)
 
         /* Randomly decide shift direction */
         if(size % 2 == 0)
-            shift_dist = size;
+            shift_dist = (ssize_t)size;
         else
             shift_dist = -((ssize_t)size);
 
-	memset (vector, 0x00, sizeof vector);
+	HDmemset(vector, 0x00, sizeof vector);
         H5T__bit_set (vector, offset, size, 1);
 
         H5T__bit_shift (vector, shift_dist, offset, size);
@@ -373,7 +373,7 @@ test_shift (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_LSB, 1);
 	if (n >= 0) {
 	    H5_FAILED();
-	    printf ("    Unable to verify all bits are zero in destination(LSB) "
+	    HDprintf ("    Unable to verify all bits are zero in destination(LSB) "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -382,7 +382,7 @@ test_shift (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_MSB, 1);
 	if (n >= 0) {
 	    H5_FAILED();
-	    printf ("    Unable to verify all bits are zero in destination(MSB) "
+	    HDprintf ("    Unable to verify all bits are zero in destination(MSB) "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -392,11 +392,11 @@ test_shift (void)
     return 0;
 
  failed:
-    printf ("    i=%d, offset=%lu, size=%lu, shift_dist=%lu\n",
+    HDprintf ("    i=%d, offset=%lu, size=%lu, shift_dist=%lu\n",
 	    i, (unsigned long)offset, (unsigned long)size,
 	    (unsigned long)shift_dist);
-    for (j=sizeof(vector)-1; j>=0; --j) printf ("%02x", vector[j]);
-    printf ("\n");
+    for (j=sizeof(vector)-1; j>=0; --j) HDprintf ("%02x", vector[j]);
+    HDprintf ("\n");
     return -1;
 }
 
@@ -428,12 +428,12 @@ test_increment (void)
     TESTING("bit increment operations");
 
     for (i=0; i<NTESTS; i++) {
-	offset = HDrand() % (8*sizeof vector);
-	size = (unsigned)HDrand() % (8*sizeof(vector)-offset);
+	offset = (size_t)HDrand() % (8 * sizeof vector);
+	size = (size_t)HDrand() % (8 * sizeof(vector) - offset);
         /* Don't want size to be 0 */
         if(size == 0) continue;
 
-	memset (vector, 0x00, sizeof vector);
+	HDmemset(vector, 0x00, sizeof vector);
         if(size>1)  /* if size=6, make a sequence like 011111 */
             H5T__bit_set (vector, offset, size-1, 1);
         else  /* if size=1, just set this one bit to 1 */
@@ -446,13 +446,13 @@ test_increment (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_LSB, 1);
 	if (size!=1 && (size_t)n!=offset+size-1) {
 	    H5_FAILED();
-	    printf ("    Unable to find first bit in destination "
+	    HDprintf ("    Unable to find first bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
         if(size==1 && n>=0) {
 	    H5_FAILED();
-	    printf ("    Unable to verify all-zero bit in destination "
+	    HDprintf ("    Unable to verify all-zero bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -464,13 +464,13 @@ test_increment (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_MSB, 1);
 	if (size!=1 && n!=(ssize_t)(offset+size-1)) {
 	    H5_FAILED();
-	    printf ("    Unable to find last bit in destination "
+	    HDprintf ("    Unable to find last bit in destination "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
         if(size==1 && n>=0) {
 	    H5_FAILED();
-	    printf ("    Unable to verify all-zero bit in destination "
+	    HDprintf ("    Unable to verify all-zero bit in destination "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -480,10 +480,10 @@ test_increment (void)
     return 0;
 
  failed:
-    printf ("    i=%d, offset=%lu, size=%lu\n",
+    HDprintf ("    i=%d, offset=%lu, size=%lu\n",
 	    i, (unsigned long)offset, (unsigned long)size);
-    for (j=sizeof(vector)-1; j>=0; --j) printf ("%02x", vector[j]);
-    printf ("\n");
+    for (j=sizeof(vector)-1; j>=0; --j) HDprintf ("%02x", vector[j]);
+    HDprintf ("\n");
     return -1;
 }
 
@@ -515,13 +515,13 @@ test_decrement (void)
     TESTING("bit decrement operations");
 
     for (i=0; i<NTESTS; i++) {
-	offset = HDrand() % (8*sizeof vector);
-	size = (unsigned)HDrand() % (8*sizeof(vector)-offset);
+	offset = (size_t)HDrand() % (8 * sizeof vector);
+	size = (size_t)HDrand() % (8 * sizeof(vector) - offset);
         /* Don't want size to be 0 */
         if(size == 0) continue;
 
         /* All-zero sequence will become 111111(size=6) after decrement */
-	memset (vector, 0x00, sizeof vector);
+	HDmemset(vector, 0x00, sizeof vector);
 
 	/* decrement the sequence by one */
         H5T__bit_dec (vector, offset, size);
@@ -530,7 +530,7 @@ test_decrement (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_LSB, 1);
 	if ((size_t)n!=offset) {
 	    H5_FAILED();
-	    printf ("    Unable to find first bit in destination "
+	    HDprintf ("    Unable to find first bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -542,7 +542,7 @@ test_decrement (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_MSB, 1);
 	if (n!=(ssize_t)(offset+size-1)) {
 	    H5_FAILED();
-	    printf ("    Unable to find last bit in destination "
+	    HDprintf ("    Unable to find last bit in destination "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -552,10 +552,10 @@ test_decrement (void)
     return 0;
 
  failed:
-    printf ("    i=%d, offset=%lu, size=%lu\n",
+    HDprintf ("    i=%d, offset=%lu, size=%lu\n",
 	    i, (unsigned long)offset, (unsigned long)size);
-    for (j=sizeof(vector)-1; j>=0; --j) printf ("%02x", vector[j]);
-    printf ("\n");
+    for (j=sizeof(vector)-1; j>=0; --j) HDprintf ("%02x", vector[j]);
+    HDprintf ("\n");
     return -1;
 }
 
@@ -587,13 +587,13 @@ test_negate (void)
     TESTING("bit negate operations");
 
     for (i=0; i<NTESTS; i++) {
-	offset = HDrand() % (8*sizeof vector);
-	size = (unsigned)HDrand() % (8*sizeof(vector)-offset);
+	offset = (size_t)HDrand() % (8 * sizeof vector);
+	size = (size_t)HDrand() % (8 * sizeof(vector) - offset);
         /* Don't want size to be 0 */
         if(size == 0) continue;
 
         /* All-zero sequence will become 111111(size=6) after negating */
-	memset (vector, 0x00, sizeof vector);
+	HDmemset(vector, 0x00, sizeof vector);
 
 	/* negate the sequence */
         H5T__bit_neg (vector, offset, size);
@@ -602,7 +602,7 @@ test_negate (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_LSB, 1);
 	if ((size_t)n!=offset) {
 	    H5_FAILED();
-	    printf ("    Unable to find first bit in destination "
+	    HDprintf ("    Unable to find first bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -614,13 +614,13 @@ test_negate (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_MSB, 1);
 	if (n!=(ssize_t)(offset+size-1)) {
 	    H5_FAILED();
-	    printf ("    Unable to find last bit in destination "
+	    HDprintf ("    Unable to find last bit in destination "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
 
         /* All-one sequence will become 000000(size=6) after negating */
-	memset (vector, 0x00, sizeof vector);
+	HDmemset(vector, 0x00, sizeof vector);
         H5T__bit_set (vector, offset, size, 1);
 
 	/* negate the sequence */
@@ -630,7 +630,7 @@ test_negate (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_LSB, 1);
 	if (n>=0) {
 	    H5_FAILED();
-	    printf ("    Unable to verify all-zero bits in destination "
+	    HDprintf ("    Unable to verify all-zero bits in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -642,7 +642,7 @@ test_negate (void)
 	n = H5T__bit_find (vector, (size_t)0, 8*sizeof(vector), H5T_BIT_MSB, 1);
 	if (n>=0) {
 	    H5_FAILED();
-	    printf ("    Unable to verify all-zero bits in destination "
+	    HDprintf ("    Unable to verify all-zero bits in destination "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
@@ -652,10 +652,10 @@ test_negate (void)
     return 0;
 
  failed:
-    printf ("    i=%d, offset=%lu, size=%lu\n",
+    HDprintf ("    i=%d, offset=%lu, size=%lu\n",
 	    i, (unsigned long)offset, (unsigned long)size);
-    for (j=sizeof(vector)-1; j>=0; --j) printf ("%02x", vector[j]);
-    printf ("\n");
+    for (j=sizeof(vector)-1; j>=0; --j) HDprintf ("%02x", vector[j]);
+    HDprintf ("\n");
     return -1;
 }
 
@@ -687,22 +687,22 @@ test_set (void)
     TESTING("bit set operations");
 
     for (i=0; i<NTESTS; i++) {
-	d_offset = HDrand() % (8*sizeof v2);
-	size = (unsigned)HDrand() % (8*sizeof(v2));
+	d_offset = (size_t)HDrand() % (8 * sizeof v2);
+	size = (size_t)HDrand() % (8 * sizeof(v2));
 	size = MIN (size, 8*sizeof(v2)-d_offset);
-	memset (v2, 0x00, sizeof v2);
+	HDmemset(v2, 0x00, sizeof v2);
 
 	/* Set some bits in v2 */
 	H5T__bit_set (v2, d_offset, size, TRUE);
 	for (j=0; j<(int)sizeof(v2); j++) if (v2[j]) break;
 	if (size>0 && j>=(int)sizeof(v2)) {
 	    H5_FAILED();
-	    puts ("    Unabled to find set region in buffer");
+	    HDputs ("    Unabled to find set region in buffer");
 	    goto failed;
 	}
 	if (0==size && j<(int)sizeof(v2)) {
 	    H5_FAILED();
-	    puts ("    Found set bits when we shouldn't have");
+	    HDputs ("    Found set bits when we shouldn't have");
 	    goto failed;
 	}
 
@@ -711,25 +711,25 @@ test_set (void)
 	n = H5T__bit_find (v2, (size_t)0, 8*sizeof(v2), H5T_BIT_LSB, 1);
 	if (size>0 && n!=(ssize_t)d_offset) {
 	    H5_FAILED();
-	    printf ("    Unable to find first set bit in destination "
+	    HDprintf ("    Unable to find first set bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (0==size && n>=0) {
 	    H5_FAILED();
-	    puts ("    Found set bits and shouldn't have!");
+	    HDputs ("    Found set bits and shouldn't have!");
 	    goto failed;
 	}
 	n = H5T__bit_find (v2, d_offset, 8*sizeof(v2)-d_offset, H5T_BIT_LSB, 0);
 	if (d_offset+size<8*sizeof(v2) && n!=(ssize_t)size) {
 	    H5_FAILED();
-	    printf ("    Unable to find last set bit in destination "
+	    HDprintf ("    Unable to find last set bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (d_offset+size==8*sizeof(v2) && n>=0) {
 	    H5_FAILED();
-	    puts ("    High-order zeros are present and shouldn't be!");
+	    HDputs ("    High-order zeros are present and shouldn't be!");
 	    goto failed;
 	}
 
@@ -740,25 +740,25 @@ test_set (void)
 	n = H5T__bit_find (v2, (size_t)0, 8*sizeof(v2), H5T_BIT_MSB, 1);
 	if (size>0 && (size_t)(n+1)!=d_offset+size) {
 	    H5_FAILED();
-	    printf ("    Unable to find last set bit in destination "
+	    HDprintf ("    Unable to find last set bit in destination "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (0==size && n>=0) {
 	    H5_FAILED();
-	    puts ("    Found set bits but shouldn't have (reverse)!");
+	    HDputs ("    Found set bits but shouldn't have (reverse)!");
 	    goto failed;
 	}
 	n = H5T__bit_find (v2, (size_t)0, d_offset+size, H5T_BIT_MSB, 0);
 	if (d_offset>0 && n+1!=(ssize_t)d_offset) {
 	    H5_FAILED();
-	    printf ("    Unable to find beginning of set bit region "
+	    HDprintf ("    Unable to find beginning of set bit region "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (0==d_offset && n>=0) {
 	    H5_FAILED();
-	    puts ("    Found leading zeros but shouldn't have!");
+	    HDputs ("    Found leading zeros but shouldn't have!");
 	    goto failed;
 	}
 
@@ -768,11 +768,11 @@ test_set (void)
     return 0;
 
  failed:
-    printf ("    i=%d, d_offset=%lu, size=%lu\n",
+    HDprintf ("    i=%d, d_offset=%lu, size=%lu\n",
 	    i, (unsigned long)d_offset, (unsigned long)size);
-    printf ("    d = 0x");
-    for (j=sizeof(v2)-1; j>=0; --j) printf ("%02x", v2[j]);
-    printf ("\n");
+    HDprintf ("    d = 0x");
+    for (j=sizeof(v2)-1; j>=0; --j) HDprintf ("%02x", v2[j]);
+    HDprintf ("\n");
     return -1;
 }
 
@@ -804,22 +804,22 @@ test_clear (void)
     TESTING("bit clear operations");
 
     for (i=0; i<NTESTS; i++) {
-	d_offset = HDrand() % (8*sizeof v2);
-	size = (unsigned)HDrand() % (8*sizeof(v2));
+	d_offset = (size_t)HDrand() % (8 * sizeof v2);
+	size = (size_t)HDrand() % (8 * sizeof(v2));
 	size = MIN (size, 8*sizeof(v2)-d_offset);
-	memset (v2, 0xff, sizeof v2);
+	HDmemset(v2, 0xff, sizeof v2);
 
 	/* Clear some bits in v2 */
 	H5T__bit_set (v2, d_offset, size, FALSE);
 	for (j=0; j<(int)sizeof(v2); j++) if (0xff!=v2[j]) break;
 	if (size>0 && j>=(int)sizeof(v2)) {
 	    H5_FAILED();
-	    puts ("    Unabled to find cleared region in buffer");
+	    HDputs ("    Unabled to find cleared region in buffer");
 	    goto failed;
 	}
 	if (0==size && j<(int)sizeof(v2)) {
 	    H5_FAILED();
-	    puts ("    Found cleared bits when we shouldn't have");
+	    HDputs ("    Found cleared bits when we shouldn't have");
 	    goto failed;
 	}
 
@@ -828,25 +828,25 @@ test_clear (void)
 	n = H5T__bit_find (v2, (size_t)0, 8*sizeof(v2), H5T_BIT_LSB, 0);
 	if (size>0 && n!=(ssize_t)d_offset) {
 	    H5_FAILED();
-	    printf ("    Unable to find first cleared bit in destination "
+	    HDprintf ("    Unable to find first cleared bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (0==size && n>=0) {
 	    H5_FAILED();
-	    puts ("    Found cleared bits and shouldn't have!");
+	    HDputs ("    Found cleared bits and shouldn't have!");
 	    goto failed;
 	}
 	n = H5T__bit_find (v2, d_offset, 8*sizeof(v2)-d_offset, H5T_BIT_LSB, 1);
 	if (d_offset+size<8*sizeof(v2) && n!=(ssize_t)size) {
 	    H5_FAILED();
-	    printf ("    Unable to find last cleared bit in destination "
+	    HDprintf ("    Unable to find last cleared bit in destination "
 		    "(n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (d_offset+size==8*sizeof(v2) && n>=0) {
 	    H5_FAILED();
-	    puts ("    High-order ones are present and shouldn't be!");
+	    HDputs ("    High-order ones are present and shouldn't be!");
 	    goto failed;
 	}
 
@@ -857,25 +857,25 @@ test_clear (void)
 	n = H5T__bit_find (v2, (size_t)0, 8*sizeof(v2), H5T_BIT_MSB, 0);
 	if (size>0 && (size_t)(n+1)!=d_offset+size) {
 	    H5_FAILED();
-	    printf ("    Unable to find last cleared bit in destination "
+	    HDprintf ("    Unable to find last cleared bit in destination "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (0==size && n>=0) {
 	    H5_FAILED();
-	    puts ("    Found cleared bits but shouldn't have (reverse)!");
+	    HDputs ("    Found cleared bits but shouldn't have (reverse)!");
 	    goto failed;
 	}
 	n = H5T__bit_find (v2, (size_t)0, d_offset+size, H5T_BIT_MSB, 1);
 	if (d_offset>0 && n+1!=(ssize_t)d_offset) {
 	    H5_FAILED();
-	    printf ("    Unable to find beginning of cleared bit region "
+	    HDprintf ("    Unable to find beginning of cleared bit region "
 		    "(reverse, n=%d)\n", (int)n);
 	    goto failed;
 	}
 	if (0==d_offset && n>=0) {
 	    H5_FAILED();
-	    puts ("    Found leading ones but shouldn't have!");
+	    HDputs ("    Found leading ones but shouldn't have!");
 	    goto failed;
 	}
 
@@ -885,23 +885,21 @@ test_clear (void)
     return 0;
 
  failed:
-    printf ("    i=%d, d_offset=%lu, size=%lu\n",
+    HDprintf ("    i=%d, d_offset=%lu, size=%lu\n",
 	    i, (unsigned long)d_offset, (unsigned long)size);
-    printf ("    d = 0x");
-    for (j=sizeof(v2)-1; j>=0; --j) printf ("%02x", v2[j]);
-    printf ("\n");
+    HDprintf ("    d = 0x");
+    for (j=sizeof(v2)-1; j>=0; --j) HDprintf ("%02x", v2[j]);
+    HDprintf ("\n");
     return -1;
 }
 
 
 /*-------------------------------------------------------------------------
- * Function:	main
+ * Function:    main
  *
  * Purpose:
  *
- * Return:	Success:
- *
- *		Failure:
+ * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
  * Programmer:	Robb Matzke
  *              Tuesday, June 16, 1998
@@ -911,7 +909,7 @@ test_clear (void)
 int
 main(void)
 {
-    int	nerrors = 0;
+    int nerrors = 0;
 
     /*
      * Open the library explicitly.
@@ -928,14 +926,14 @@ main(void)
     nerrors += test_negate() < 0 ? 1 : 0;
 
     if(nerrors) {
-        printf("***** %u FAILURE%s! *****\n",
+        HDprintf("***** %u FAILURE%s! *****\n",
                nerrors, 1 == nerrors ? "" : "S");
-        exit(1);
+        HDexit(EXIT_FAILURE);
     }
-    printf("All bit tests passed.\n");
+    HDprintf("All bit tests passed.\n");
 
     H5close();
 
-    return 0;
-}
+    HDexit(EXIT_SUCCESS);
+} /* end main() */
 
