@@ -43,6 +43,7 @@ typedef struct {
     hbool_t is_absolute;            /* Whether the traversal has absolute paths */
     const char *base_grp_name;      /* Name of the group that serves as the base
                                      * for iteration */
+    unsigned fields;                /* Fields needed in H5O_info_t struct */
 } trav_ud_traverse_t;
 
 typedef struct {
@@ -113,7 +114,7 @@ h5trav_set_verbose(int print_verbose)
  *-------------------------------------------------------------------------
  */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: trav_addr_add
  *
@@ -139,7 +140,6 @@ trav_addr_add(trav_addr_t *visited, haddr_t addr, const char *path)
     visited->objs[idx].path = HDstrdup(path);
 } /* end trav_addr_add() */
 
-
 /*-------------------------------------------------------------------------
  * Function: trav_addr_visited
  *
@@ -163,7 +163,6 @@ trav_addr_visited(trav_addr_t *visited, haddr_t addr)
     return(NULL);
 } /* end trav_addr_visited() */
 
-
 /*-------------------------------------------------------------------------
  * Function: traverse_cb
  *
@@ -183,7 +182,7 @@ traverse_cb(hid_t loc_id, const char *path, const H5L_info_t *linfo,
     if(udata->is_absolute) {
         size_t base_len = HDstrlen(udata->base_grp_name);
         size_t add_slash = base_len ? ((udata->base_grp_name)[base_len - 1] != '/') : 1;
-        size_t new_name_len = base_len + add_slash + HDstrlen(path) + 1;
+        size_t new_name_len = base_len + add_slash + HDstrlen(path) + 1 + 3; /* Extra "+3" to quiet GCC warning - 2019/07/05, QAK */
 
         if(NULL == (new_name = (char*)HDmalloc(new_name_len)))
             return(H5_ITER_ERROR);
@@ -201,7 +200,7 @@ traverse_cb(hid_t loc_id, const char *path, const H5L_info_t *linfo,
         H5O_info_t oinfo;
 
         /* Get information about the object */
-        if(H5Oget_info_by_name(loc_id, path, &oinfo, H5P_DEFAULT) < 0) {
+        if(H5Oget_info_by_name2(loc_id, path, &oinfo, udata->fields, H5P_DEFAULT) < 0) {
             if(new_name)
                 HDfree(new_name);
             return(H5_ITER_ERROR);
@@ -238,7 +237,7 @@ traverse_cb(hid_t loc_id, const char *path, const H5L_info_t *linfo,
     return(H5_ITER_CONT);
 } /* end traverse_cb() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: traverse
  *
@@ -251,14 +250,14 @@ traverse_cb(hid_t loc_id, const char *path, const H5L_info_t *linfo,
  */
 static int
 traverse(hid_t file_id, const char *grp_name, hbool_t visit_start,
-        hbool_t recurse, const trav_visitor_t *visitor)
+        hbool_t recurse, const trav_visitor_t *visitor, unsigned fields)
 {
     H5O_info_t  oinfo;          /* Object info for starting group */
-    int         ret_value = SUCCEED;
+    int         ret_value = 0;
 
     /* Get info for starting object */
-    if(H5Oget_info_by_name(file_id, grp_name, &oinfo, H5P_DEFAULT) < 0)
-        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Oget_info_by_name failed");
+    if(H5Oget_info_by_name2(file_id, grp_name, &oinfo, fields, H5P_DEFAULT) < 0)
+        H5TOOLS_GOTO_ERROR((-1), "H5Oget_info_by_name failed");
 
     /* Visit the starting object */
     if(visit_start && visitor->visit_obj)
@@ -282,17 +281,18 @@ traverse(hid_t file_id, const char *grp_name, hbool_t visit_start,
         udata.visitor = visitor;
         udata.is_absolute = (*grp_name == '/');
         udata.base_grp_name = grp_name;
+        udata.fields = fields;
 
         /* Check for iteration of links vs. visiting all links recursively */
         if(recurse) {
             /* Visit all links in group, recursively */
             if(H5Lvisit_by_name(file_id, grp_name, trav_index_by, trav_index_order, traverse_cb, &udata, H5P_DEFAULT) < 0)
-                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Lvisit_by_name failed");
+                H5TOOLS_GOTO_ERROR((-1), "H5Lvisit_by_name failed");
         } /* end if */
         else {
             /* Iterate over links in group */
             if(H5Literate_by_name(file_id, grp_name, trav_index_by, trav_index_order, NULL, traverse_cb, &udata, H5P_DEFAULT) < 0)
-                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Literate_by_name failed");
+                H5TOOLS_GOTO_ERROR((-1), "H5Literate_by_name failed");
         } /* end else */
 
         /* Free visited addresses table */
@@ -310,7 +310,7 @@ done:
     return ret_value;
 }
 
-
+
 /*-------------------------------------------------------------------------
  * Function: trav_info_add
  *
@@ -356,15 +356,15 @@ trav_fileinfo_add(trav_info_t *info, hid_t loc_id)
     size_t idx = info->nused - 1;
 
     if ( info->paths[idx].path && HDstrcmp(info->paths[idx].path, "."))
-      H5Oget_info_by_name(loc_id, info->paths[idx].path, &oinfo, H5P_DEFAULT);
+      H5Oget_info_by_name2(loc_id, info->paths[idx].path, &oinfo, H5O_INFO_BASIC, H5P_DEFAULT);
     else
-      H5Oget_info(loc_id, &oinfo);
+      H5Oget_info2(loc_id, &oinfo, H5O_INFO_BASIC);
 
     info->paths[idx].objno = oinfo.addr;
     info->paths[idx].fileno = oinfo.fileno;
 } /* end trav_fileinfo_add() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: trav_info_visit_obj
  *
@@ -394,7 +394,7 @@ trav_info_visit_obj(const char *path, const H5O_info_t *oinfo,
     return(0);
 } /* end trav_info_visit_obj() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: trav_info_visit_lnk
  *
@@ -413,7 +413,7 @@ trav_info_visit_lnk(const char *path, const H5L_info_t *linfo, void *udata)
     return(0);
 } /* end trav_info_visit_lnk() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: h5trav_getinfo
  *
@@ -428,7 +428,7 @@ int
 h5trav_getinfo(hid_t file_id, trav_info_t *info)
 {
     trav_visitor_t info_visitor;        /* Visitor structure for trav_info_t's */
-    int            ret_value = SUCCEED;
+    int            ret_value = 0;
 
     /* Init visitor structure */
     info_visitor.visit_obj = trav_info_visit_obj;
@@ -436,8 +436,8 @@ h5trav_getinfo(hid_t file_id, trav_info_t *info)
     info_visitor.udata = info;
 
     /* Traverse all objects in the file, visiting each object & link */
-    if(traverse(file_id, "/", TRUE, TRUE, &info_visitor) < 0)
-        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "traverse failed");
+    if(traverse(file_id, "/", TRUE, TRUE, &info_visitor, H5O_INFO_BASIC) < 0)
+        H5TOOLS_GOTO_ERROR((-1), "traverse failed");
 
 done:
     return ret_value;
@@ -499,7 +499,7 @@ trav_info_init(const char *filename, hid_t fileid, trav_info_t **_info)
     *_info = info;
 } /* end trav_info_init() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: trav_info_free
  *
@@ -534,7 +534,7 @@ trav_info_free(trav_info_t *info)
  *-------------------------------------------------------------------------
  */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: trav_table_visit_obj
  *
@@ -561,7 +561,7 @@ trav_table_visit_obj(const char *path, const H5O_info_t *oinfo,
     return 0;
 } /* end trav_table_visit_obj() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: trav_table_visit_lnk
  *
@@ -580,7 +580,7 @@ trav_table_visit_lnk(const char *path, const H5L_info_t H5_ATTR_UNUSED *linfo, v
     return 0;
 } /* end trav_table_visit_lnk() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: h5trav_gettable
  *
@@ -594,7 +594,7 @@ int
 h5trav_gettable(hid_t fid, trav_table_t *table)
 {
     trav_visitor_t table_visitor;       /* Visitor structure for trav_table_t's */
-    int            ret_value = SUCCEED;
+    int            ret_value = 0;
 
     /* Init visitor structure */
     table_visitor.visit_obj = trav_table_visit_obj;
@@ -602,8 +602,8 @@ h5trav_gettable(hid_t fid, trav_table_t *table)
     table_visitor.udata = table;
 
     /* Traverse all objects in the file, visiting each object & link */
-    if(traverse(fid, "/", TRUE, TRUE, &table_visitor) < 0)
-        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "traverse failed");
+    if(traverse(fid, "/", TRUE, TRUE, &table_visitor, H5O_INFO_BASIC) < 0)
+        H5TOOLS_GOTO_ERROR((-1), "traverse failed");
 
 done:
     return ret_value;
@@ -661,9 +661,7 @@ h5trav_getindext(const char *name, const trav_table_t *table)
  *-------------------------------------------------------------------------
  */
 static void
-trav_table_add(trav_table_t *table,
-                    const char *path,
-                    const H5O_info_t *oinfo)
+trav_table_add(trav_table_t *table, const char *path, const H5O_info_t *oinfo)
 {
     size_t new_obj;
 
@@ -718,9 +716,9 @@ trav_table_addlink(trav_table_t *table, haddr_t objno, const char *path)
                 table->objs[i].links[n].new_name = (char *)HDstrdup(path);
 
                 return;
-            } /* end for */
+            } /* end if */
         } /* end for */
-    }
+    } /* end if */
 }
 
 
@@ -821,19 +819,19 @@ trav_attr(hid_t
     const char          *buf = op_data->path;
 
     if((strlen(buf)==1) && (*buf=='/'))
-        printf(" %-10s %s%s", "attribute", buf, attr_name);
+        HDprintf(" %-10s %s%s", "attribute", buf, attr_name);
     else
-        printf(" %-10s %s/%s", "attribute", buf, attr_name);
+        HDprintf(" %-10s %s/%s", "attribute", buf, attr_name);
 
 #ifdef H5TRAV_PRINT_SPACE
     if(trav_verbosity < 2) {
 #endif
-        printf("\n");
+        HDprintf("\n");
 #ifdef H5TRAV_PRINT_SPACE
     }
     else {
-        hid_t               attr = -1;
-        hid_t               space = -1;
+        hid_t               attr = H5I_INVALID_HID;
+        hid_t               space = H5I_INVALID_HID;
         hsize_t             size[H5S_MAX_RANK];
         int                 ndims;
         int                 i;
@@ -848,26 +846,26 @@ trav_attr(hid_t
             switch(space_type) {
                 case H5S_SCALAR:
                     /* scalar dataspace */
-                    printf(" scalar\n");
+                    HDprintf(" scalar\n");
                     break;
 
                 case H5S_SIMPLE:
                     /* simple dataspace */
-                    printf(" {");
+                    HDprintf(" {");
                     for (i = 0; i < ndims; i++) {
-                        printf("%s" HSIZE_T_FORMAT, i?", ":"", size[i]);
+                        HDprintf("%s" HSIZE_T_FORMAT, i?", ":"", size[i]);
                     }
-                    printf("}\n");
+                    HDprintf("}\n");
                     break;
 
                 case H5S_NULL:
                     /* null dataspace */
-                    printf(" null\n");
+                    HDprintf(" null\n");
                     break;
 
                 default:
                     /* Unknown dataspace type */
-                    printf(" unknown\n");
+                    HDprintf(" unknown\n");
                     break;
             } /* end switch */
 
@@ -880,7 +878,7 @@ trav_attr(hid_t
     return(0);
 }
 
-
+
 /*-------------------------------------------------------------------------
  * Function: trav_print_visit_obj
  *
@@ -892,7 +890,7 @@ trav_attr(hid_t
  */
 static int
 trav_print_visit_obj(const char *path, const H5O_info_t *oinfo,
-        const char *already_visited, void *udata)
+    const char *already_visited, void *udata)
 {
     trav_print_udata_t *print_udata = (trav_print_udata_t *)udata;
     /* Print the name of the object */
@@ -901,21 +899,21 @@ trav_print_visit_obj(const char *path, const H5O_info_t *oinfo,
      */
     switch(oinfo->type) {
         case H5O_TYPE_GROUP:
-            printf(" %-10s %s", "group", path);
+            HDprintf(" %-10s %s", "group", path);
             break;
 
         case H5O_TYPE_DATASET:
-            printf(" %-10s %s", "dataset", path);
+            HDprintf(" %-10s %s", "dataset", path);
             break;
 
         case H5O_TYPE_NAMED_DATATYPE:
-            printf(" %-10s %s", "datatype", path);
+            HDprintf(" %-10s %s", "datatype", path);
             break;
 
         case H5O_TYPE_UNKNOWN:
         case H5O_TYPE_NTYPES:
         default:
-            printf(" %-10s %s", "unknown object type", path);
+            HDprintf(" %-10s %s", "unknown object type", path);
             break;
     } /* end switch */
 
@@ -925,19 +923,19 @@ trav_print_visit_obj(const char *path, const H5O_info_t *oinfo,
 
         op_data.path = path;
         /* Finish printing line about object */
-        printf("\n");
+        HDprintf("\n");
         if(trav_verbosity > 0)
             H5Aiterate_by_name(print_udata->fid, path, trav_index_by, trav_index_order,
                                NULL, trav_attr, &op_data, H5P_DEFAULT);
     }
     else
         /* Print the link's original name */
-        printf(" -> %s\n", already_visited);
+        HDprintf(" -> %s\n", already_visited);
 
     return(0);
 } /* end trav_print_visit_obj() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: trav_print_visit_lnk
  *
@@ -960,12 +958,12 @@ trav_print_visit_lnk(const char *path, const H5L_info_t *linfo, void *udata)
                 if(targbuf) {
                     if(H5Lget_val(print_udata->fid, path, targbuf, linfo->u.val_size + 1, H5P_DEFAULT) < 0)
                         targbuf[0] = 0;
-                    printf(" %-10s %s -> %s\n", "link", path, targbuf);
+                    HDprintf(" %-10s %s -> %s\n", "link", path, targbuf);
                     HDfree(targbuf);
                 }
             } /* end if */
             else
-                printf(" %-10s %s ->\n", "link", path);
+                HDprintf(" %-10s %s ->\n", "link", path);
             break;
 
         case H5L_TYPE_EXTERNAL:
@@ -979,12 +977,12 @@ trav_print_visit_lnk(const char *path, const H5L_info_t *linfo, void *udata)
                     if(H5Lget_val(print_udata->fid, path, targbuf, linfo->u.val_size + 1, H5P_DEFAULT) < 0)
                         targbuf[0] = 0;
                     if(H5Lunpack_elink_val(targbuf, linfo->u.val_size, NULL, &filename, &objname) >= 0)
-                        printf(" %-10s %s -> %s %s\n", "ext link", path, filename, objname);
+                        HDprintf(" %-10s %s -> %s %s\n", "ext link", path, filename, objname);
                     HDfree(targbuf);
                 }
             } /* end if */
             else
-                printf(" %-10s %s ->\n", "ext link", path);
+                HDprintf(" %-10s %s ->\n", "ext link", path);
             break;
 
         case H5L_TYPE_HARD:
@@ -994,14 +992,14 @@ trav_print_visit_lnk(const char *path, const H5L_info_t *linfo, void *udata)
         case H5L_TYPE_ERROR:
         case H5L_TYPE_MAX:
         default:
-            printf(" %-10s %s -> ???\n", "unknown type of UD link", path);
+            HDprintf(" %-10s %s -> ???\n", "unknown type of UD link", path);
             break;
     } /* end switch() */
 
     return(0);
 } /* end trav_print_visit_lnk() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: h5trav_print
  *
@@ -1016,7 +1014,7 @@ h5trav_print(hid_t fid)
 {
     trav_print_udata_t print_udata;     /* User data for traversal */
     trav_visitor_t print_visitor;       /* Visitor structure for printing objects */
-    int            ret_value = SUCCEED;
+    int ret_value = 0;
 
     /* Init user data for printing */
     print_udata.fid = fid;
@@ -1027,14 +1025,14 @@ h5trav_print(hid_t fid)
     print_visitor.udata = &print_udata;
 
     /* Traverse all objects in the file, visiting each object & link */
-    if(traverse(fid, "/", TRUE, TRUE, &print_visitor) < 0)
-        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "traverse failed");
+    if(traverse(fid, "/", TRUE, TRUE, &print_visitor, H5O_INFO_BASIC) < 0)
+        H5TOOLS_GOTO_ERROR(FAIL, "traverse failed");
 
 done:
     return ret_value;
 }
 
-
+
 /*-------------------------------------------------------------------------
  * Function: h5trav_visit
  *
@@ -1047,10 +1045,10 @@ done:
 int
 h5trav_visit(hid_t fid, const char *grp_name, hbool_t visit_start,
     hbool_t recurse, h5trav_obj_func_t visit_obj, h5trav_lnk_func_t visit_lnk,
-    void *udata)
+    void *udata, unsigned fields)
 {
     trav_visitor_t visitor;             /* Visitor structure for objects */
-    int            ret_value = SUCCEED;
+    int            ret_value = 0;
 
     /* Init visitor structure */
     visitor.visit_obj = visit_obj;
@@ -1058,8 +1056,8 @@ h5trav_visit(hid_t fid, const char *grp_name, hbool_t visit_start,
     visitor.udata = udata;
 
     /* Traverse all objects in the file, visiting each object & link */
-    if(traverse(fid, grp_name, visit_start, recurse, &visitor) < 0)
-        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "traverse failed");
+    if(traverse(fid, grp_name, visit_start, recurse, &visitor, fields) < 0)
+        H5TOOLS_GOTO_ERROR((-1), "traverse failed");
 
 done:
     return ret_value;
@@ -1077,8 +1075,8 @@ done:
 herr_t
 symlink_visit_add(symlink_trav_t *visited, H5L_type_t type, const char *file, const char *path)
 {
-    herr_t    ret_value = SUCCEED;
-    size_t    idx;         /* Index of address to use */
+    size_t idx;         /* Index of address to use */
+    herr_t ret_value = SUCCEED;
 
     /* Allocate space if necessary */
     if(visited->nused == visited->nalloc) {
@@ -1086,7 +1084,7 @@ symlink_visit_add(symlink_trav_t *visited, H5L_type_t type, const char *file, co
 
         visited->nalloc = MAX(1, visited->nalloc * 2);
         if(NULL == (tmp_ptr = HDrealloc(visited->objs, visited->nalloc * sizeof(symlink_trav_path_t))))
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "visited data structure realloc failed");
+            H5TOOLS_GOTO_ERROR(FAIL, "visited data structure realloc failed");
         visited->objs = (symlink_trav_path_t *)tmp_ptr;
     } /* end if */
 
@@ -1100,7 +1098,7 @@ symlink_visit_add(symlink_trav_t *visited, H5L_type_t type, const char *file, co
     if(type == H5L_TYPE_EXTERNAL) {
         if(NULL == (visited->objs[idx].file = HDstrdup(file))) {
             visited->nused--;
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "visited data structure name allocation failed");
+            H5TOOLS_GOTO_ERROR(FAIL, "visited data structure name allocation failed");
         } /* end if */
     } /* end if */
 
@@ -1108,14 +1106,14 @@ symlink_visit_add(symlink_trav_t *visited, H5L_type_t type, const char *file, co
         visited->nused--;
         if(visited->objs[idx].file)
             HDfree (visited->objs[idx].file);
-        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "visited data structure path allocation failed");
+        H5TOOLS_GOTO_ERROR(FAIL, "visited data structure path allocation failed");
     } /* end if */
 
 done:
     return ret_value;
 } /* end symlink_visit_add() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: symlink_is_visited
  *
